@@ -82,6 +82,7 @@ void DeviceControllItem::setDevices(const QList<NetworkDeviceBase *> &devices)
                 m_devices.removeOne(device);
                 standardItem()->setData(QVariant::fromValue<QList<NetworkDeviceBase *>>(m_devices), DeviceDataRole);
             });
+            connect(device, &NetworkDeviceBase::availableChanged, this, &DeviceControllItem::onUpdateAvailable);
             m_devices << device;
         }
     }
@@ -98,6 +99,8 @@ void DeviceControllItem::updateView()
 {
     // 更新状态显示
     standardItem()->setData(QVariant::fromValue<QList<NetworkDeviceBase *>>(m_devices), DeviceDataRole);
+    // 更新available的内容
+    onUpdateAvailable();
 }
 
 NetItemType DeviceControllItem::itemType()
@@ -120,6 +123,20 @@ void DeviceControllItem::initItemText()
         standardItem()->setText(tr("Wired Network"));
 }
 
+void DeviceControllItem::onUpdateAvailable()
+{
+    bool available = false;
+    for (NetworkDeviceBase *device : m_devices) {
+        if (!device->available())
+            continue;
+
+        available = true;
+        break;
+    }
+
+    standardItem()->setData(QVariant::fromValue(available), NetItemRole::AvailableRole);
+}
+
 WiredControllItem::WiredControllItem(QWidget *parent, WiredDevice *device)
     : NetItem(parent)
     , m_device(device)
@@ -130,11 +147,15 @@ WiredControllItem::WiredControllItem(QWidget *parent, WiredDevice *device)
     standardItem()->setData(NetItemType::WiredControllViewItem, NetItemRole::TypeRole);
     standardItem()->setData(QVariant::fromValue(DeviceType::Wired), NetItemRole::DeviceTypeRole);
     standardItem()->setData(QVariant::fromValue(m_device), NetItemRole::DeviceDataRole);
+    standardItem()->setData(QVariant::fromValue(m_device->available()), NetItemRole::AvailableRole);
     standardItem()->setFontSize(DFontSizeManager::T5);
     connect(m_device, &WiredDevice::destroyed, this, [ this ] {
         m_device = nullptr;
         standardItem()->setData(0, NetItemRole::DeviceDataRole);
     });
+    connect(m_device, &WiredDevice::availableChanged, this, [ this ] {
+        standardItem()->setData(QVariant::fromValue(m_device->available()), NetItemRole::AvailableRole);
+    });
 }
 
 WiredControllItem::~WiredControllItem()
@@ -166,11 +187,15 @@ WirelessControllItem::WirelessControllItem(QWidget *parent, WirelessDevice *devi
     standardItem()->setData(NetItemType::WirelessControllViewItem, NetItemRole::TypeRole);
     standardItem()->setData(QVariant::fromValue(m_device), NetItemRole::DeviceDataRole);
     standardItem()->setData(QVariant::fromValue(DeviceType::Wireless), NetItemRole::DeviceTypeRole);
+    standardItem()->setData(QVariant::fromValue(m_device->available()), NetItemRole::AvailableRole);
     standardItem()->setFontSize(DFontSizeManager::T5);
     connect(m_device, &WirelessDevice::destroyed, this, [ this ] {
         m_device = nullptr;
         standardItem()->setData(0, NetItemRole::DeviceDataRole);
     });
+    connect(m_device, &WirelessDevice::availableChanged, this, [ this ] {
+        standardItem()->setData(QVariant::fromValue(m_device->available()), NetItemRole::AvailableRole);
+    });
 }
 
 WirelessControllItem::~WirelessControllItem()
@@ -267,10 +292,14 @@ void WiredItem::initUi()
     standardItem()->setData(QVariant::fromValue(m_device), NetItemRole::DeviceDataRole);
     standardItem()->setData(QVariant::fromValue(static_cast<void *>(m_connection)), NetItemRole::DataRole);
     standardItem()->setData(QVariant::fromValue(DeviceType::Wired), NetItemRole::DeviceTypeRole);
+    standardItem()->setData(QVariant::fromValue(m_device->available()), NetItemRole::AvailableRole);
     connect(m_device, &WiredDevice::destroyed, this, [ this ] {
         m_device = nullptr;
         standardItem()->setData(0, NetItemRole::DeviceDataRole);
     });
+    connect(m_device, &WiredDevice::availableChanged, this, [ this ]{
+        standardItem()->setData(QVariant::fromValue(m_device->available()), NetItemRole::AvailableRole);
+    });
 }
 
 void WiredItem::connectNetwork()
@@ -296,6 +325,7 @@ WirelessItem::WirelessItem(QWidget *parent, WirelessDevice *device, AccessPoints
     , m_ssidEdit(nullptr)
     , m_wirelessConnect(new WirelessConnect(this, device, ap))
     , m_connectButton(nullptr)
+    , m_needCheckActiving(false)
     , m_panel(panel)
 {
     initUi(parent);
@@ -390,16 +420,31 @@ void WirelessItem::initUi(QWidget *parent)
     standardItem()->setData(QVariant::fromValue(m_device), NetItemRole::DeviceDataRole);
     standardItem()->setData(QVariant::fromValue(DeviceType::Wireless), NetItemRole::DeviceTypeRole);
     standardItem()->setData(QVariant::fromValue(static_cast<void *>(m_accessPoint)), NetItemRole::DataRole);
+    standardItem()->setData(QVariant::fromValue(m_device->available()), NetItemRole::AvailableRole);
     standardItem()->setFontSize(DFontSizeManager::T6);
     connect(m_device, &WirelessDevice::destroyed, this, [this] {
         m_device = nullptr;
         standardItem()->setData(0, NetItemRole::DeviceDataRole);
     });
+    connect(m_device, &WirelessDevice::availableChanged, this, [ this ] {
+        standardItem()->setData(QVariant::fromValue(m_device->available()), NetItemRole::AvailableRole);
+        m_stackWidget->setEnabled(m_device->available());
+    });
+    m_stackWidget->setEnabled(m_device->available());
 }
 
 void WirelessItem::initConnection()
 {
     connect(m_wirelessConnect, &WirelessConnect::passwordError, this, &WirelessItem::onInputPassword, Qt::QueuedConnection);
+    connect(m_accessPoint, &AccessPoints::securedChanged, this, [ = ] {
+        updateSrcirityIcon();
+        Q_EMIT requestUpdate();
+    }, Qt::QueuedConnection);
+    connect(m_accessPoint, &AccessPoints::strengthChanged, this, [ = ] {
+        updateWifiIcon();
+        Q_EMIT requestUpdate();
+    }, Qt::QueuedConnection);
+    connect(m_accessPoint, &AccessPoints::destroyed, this, [ this ] { m_accessPoint = nullptr; }, Qt::DirectConnection);
 }
 
 void WirelessItem::updateSrcirityIcon()
@@ -453,6 +498,7 @@ void WirelessItem::onConnection()
 
 void WirelessItem::expandWidget(ExpandWidget type, bool autoDisconnect)
 {
+    m_needCheckActiving = false;
     switch (type) {
     case ExpandWidget::Hide:
         if(m_expandItem->isVisible()) {
@@ -480,20 +526,16 @@ void WirelessItem::expandWidget(ExpandWidget type, bool autoDisconnect)
         // 如果当前需要输入密码的ap不是处理正在连接状态，则隐藏起来，目的是为了处理在控制中心快速切换ap导致连接状态错误的问题
         const QString ssidWaitingForPassword = m_panel->ssidWaitingForPassword();
         if (m_accessPoint && ssidWaitingForPassword == m_accessPoint->ssid()) {
-            if (m_accessPoint->status() != ConnectionStatus::Activating) {
-                expandWidget(ExpandWidget::Hide);
-                break;
-            }
             // 有时候显示密码输入框时, ap的status还没有来得变更，有可能会在几毫秒(不确定)后变更，需要绑定信号进行处理
             connect(m_accessPoint, &AccessPoints::connectionStatusChanged, this, &WirelessItem::onApConnectionStatusChanged, Qt::UniqueConnection);
+            if (m_accessPoint->status() != ConnectionStatus::Activating) {
+                expandWidget(ExpandWidget::Hide);
+                m_needCheckActiving = true;
+                break;
+            }
         }
-        m_expandItem->setVisible(true);
-        m_topItem->setVisible(true);
-        standardItem()->setSizeHint(QSize(-1, 130));
-        m_stackWidget->setCurrentIndex(type);
-        m_passwdEdit->lineEdit()->setFocus();
-        checkInputValid();
-        m_passwdEdit->setAlert(!m_passwdEdit->text().isEmpty());
+
+        showPassword();
         break;
     }
     emit sizeChanged();
@@ -503,9 +545,23 @@ void WirelessItem::onApConnectionStatusChanged(ConnectionStatus status)
 {
     if (status != ConnectionStatus::Activating && expandVisible()) {
         expandWidget(ExpandWidget::Hide);
+    } else if (m_needCheckActiving && status == ConnectionStatus::Activating && m_accessPoint->secured()) {
+        showPassword();
+        m_needCheckActiving = false;
     }
 }
 
+void WirelessItem::showPassword()
+{
+    m_expandItem->setVisible(true);
+    m_topItem->setVisible(true);
+    standardItem()->setSizeHint(QSize(-1, 130));
+    m_stackWidget->setCurrentIndex(ExpandWidget::ShowPassword);
+    m_passwdEdit->lineEdit()->setFocus();
+    checkInputValid();
+    m_passwdEdit->setAlert(!m_passwdEdit->text().isEmpty());
+}
+
 void WirelessItem::createPasswordEdit()
 {
     //　密码输入窗
@@ -603,7 +659,7 @@ void WirelessItem::connectNetwork()
         // 密码框未显示前尝试直接连接
         if (!m_expandItem->isVisible()) {
             if (m_accessPoint) {
-                m_wirelessConnect->connectNetwork();
+                m_device->connectNetwork(m_accessPoint);
             } else {
                 expandWidget(ExpandWidget::ShowSSID);
             }
@@ -638,11 +694,6 @@ void WirelessItem::expandPasswordInput()
     m_wirelessConnect->getoldPassword();
 }
 
-void WirelessItem::onAirplaneModeChanged(bool airplaneModeEnabled)
-{
-    m_stackWidget->setDisabled(airplaneModeEnabled);
-}
-
 void WirelessItem::onConnectHidden()
 {
     QString ssid = m_ssidEdit->text();
@@ -691,7 +742,7 @@ void WirelessItem::onCancel()
                 lastConnection = conn;
         }
 
-        if (lastConnection)
+        if (lastConnection && lastConnection->accessPoints())
             m_device->connectNetwork(lastConnection->accessPoints());
 
     }
