@@ -16,6 +16,7 @@
 #include <DGuiApplicationHelper>
 #include <DSwitchButton>
 #include <dloadingindicator.h>
+#include <QtMath>
 
 #include <QTimer>
 #include <QScroller>
@@ -52,10 +53,6 @@ private:
 
 void ScrollArea::setVisible(bool visible)
 {
-    QWidget *w = qobject_cast<QWidget *>(parent());
-    if (w) {
-        w->setWindowFlag(Qt::WindowDoesNotAcceptFocus, !visible);
-    }
     if (!visible && m_panel->closeOnClear()) {
         m_panel->clear();
     }
@@ -69,7 +66,6 @@ NetworkPanel::NetworkPanel(QObject *parent)
     , m_applet(new ScrollArea(this))
     , m_centerWidget(new QWidget(m_applet))
     , m_netListView(new DListView(m_centerWidget))
-    , m_airplaneMode(new DBusAirplaneMode("com.deepin.daemon.AirplaneMode", "/com/deepin/daemon/AirplaneMode", QDBusConnection::systemBus(), this))
     , m_updateTimer(new QTimer(this))
 {
     initUi();
@@ -115,7 +111,6 @@ void NetworkPanel::initUi()
     m_netListView->setItemRadius(0);
 
     NetworkDelegate *delegate = new NetworkDelegate(m_netListView);
-    delegate->setDBusAirplaneMode(m_airplaneMode);
     delegate->setMargins(QMargins(10, 0, 6, 0));
     m_netListView->setItemDelegate(delegate);
     connect(delegate, &NetworkDelegate::refreshClicked, this, &NetworkPanel::onRefreshClicked);
@@ -227,7 +222,7 @@ void NetworkPanel::onEnabledClicked(const QModelIndex &index, const bool enabled
     case NetItemType::DeviceControllViewItem: {
         QList<NetworkDeviceBase *> devices = index.data(DeviceDataRole).value<QList<NetworkDeviceBase *>>();
         for (NetworkDeviceBase *device : devices) {
-            if (device->isEnabled() != enabled)
+            if (device->available() && device->isEnabled() != enabled)
                 device->setEnabled(enabled);
         }
         break;
@@ -385,20 +380,20 @@ void NetworkPanel::updateItems()
                 if (!apCtrl) {
                     apCtrl = new WirelessItem(m_netListView->viewport(), device, ap, this);
                     connect(apCtrl, &WirelessItem::sizeChanged, this, &NetworkPanel::refreshItems);
-                    connect(m_airplaneMode, &DBusAirplaneMode::EnabledChanged, apCtrl, &WirelessItem::onAirplaneModeChanged);
+                    connect(apCtrl, &WirelessItem::requestUpdate, this, [=] { m_netListView->update(); });
                 }
                 apCtrl->updateView();
-                apCtrl->onAirplaneModeChanged(m_airplaneMode->wifiEnabled());
 
                 apCtrl->standardItem()->setData(sortIndex++, sortRole);
                 items << apCtrl;
             }
-            if (!m_airplaneMode->wifiEnabled()) {
+            if (device->available()) {
                 // 连接隐藏网络
                 WirelessItem *apCtrl = findWirelessItem(nullptr, device);
                 if (!apCtrl) {
                     apCtrl = new WirelessItem(m_netListView->viewport(), device, nullptr, this);
                     connect(apCtrl, &WirelessItem::sizeChanged, this, &NetworkPanel::refreshItems);
+                    connect(apCtrl, &WirelessItem::requestUpdate, this, [=] { m_netListView->update(); });
                 }
                 apCtrl->updateView();
 
@@ -463,13 +458,7 @@ void NetworkPanel::updateView()
     updateItems();
     refreshItems();
     passwordError(QString(), QString());
-    if (m_items.isEmpty()) {
-        // 1s后依旧无网络设备则退出
-        QTimer::singleShot(1000, this, [ this ] {
-            if (m_items.isEmpty())
-                qApp->quit();
-        });
-    }
+
     // 网络设备数量大于1时，需要延迟发送信号，确保数据初始化完成，避免网络面板闪烁，解决bug119717
     QTimer::singleShot(200, this, [ this ] {
         if (m_model->rowCount() > 0)
@@ -628,7 +617,7 @@ QWidget *NetworkPanel::itemApplet()
 void NetworkPanel::setControlBackground()
 {
     QPalette backgroud = m_applet->palette();
-    backgroud.setColor(QPalette::Background, ThemeManager::instance()->backgroundColor());
+    backgroud.setColor(QPalette::Background, Qt::transparent);
     m_applet->setAutoFillBackground(true);
     m_applet->setPalette(backgroud);
 }
@@ -644,14 +633,14 @@ void NetworkPanel::onClickListView(const QModelIndex &index)
 {
     // 如果当前点击的是连接隐藏网络或者无线网络，且开启了飞行模式，则不让点击
     NetItemType type = index.data(NetItemRole::TypeRole).value<NetItemType>();
-    if ((type == WirelessHiddenViewItem || type == WirelessViewItem) && m_airplaneMode->wifiEnabled())
+    if ((type == WirelessHiddenViewItem || type == WirelessViewItem) && !index.data(NetItemRole::AvailableRole).toBool())
         return;
 
     NetItem *oldSelectItem = selectItem();
     NetItem *newSelectItem = m_items.at(index.row());
     if (newSelectItem != oldSelectItem && oldSelectItem) {
         WirelessItem *item = static_cast<WirelessItem *>(oldSelectItem);
-        item->expandWidget(WirelessItem::Hide); // 选择切换时隐藏输入框
+        item->expandWidget(WirelessItem::Hide, false); // 选择切换时隐藏输入框
     }
     switch (type) {
     case WirelessHiddenViewItem:
@@ -696,7 +685,8 @@ void NetworkPanel::passwordError(const QString &dev, const QString &ssid, bool w
         clear();
     }
     if (!m_reconnectSsid.isEmpty()) {
-        QTimer::singleShot(0, this, &NetworkPanel::expandPasswordInput);
+        // 需要延时一段时间再展开密码输入框，否则界面和列表还没有显示出来时，输入框无法获得焦点
+        QTimer::singleShot(150, this, &NetworkPanel::expandPasswordInput);
     }
 }
 
@@ -789,7 +779,6 @@ NetworkDelegate::NetworkDelegate(QAbstractItemView *parent)
     , m_refreshIconTimer(new QTimer(this))
     , m_currentDegree(0)
     , m_refreshTimer(new QTimer(this))
-    , m_airplaneMode(nullptr)
 {
     connect(m_refreshTimer, &QTimer::timeout, this, [this]() {
         this->m_currentDegree += 14;
@@ -826,11 +815,6 @@ NetworkDelegate::~NetworkDelegate()
         m_refreshTimer->stop();
 }
 
-void NetworkDelegate::setDBusAirplaneMode(DBusAirplaneMode *airplane)
-{
-    m_airplaneMode = airplane;
-}
-
 void NetworkDelegate::initStyleOption(QStyleOptionViewItem *option, const QModelIndex &index) const
 {
     option->state &= ~QStyle::State_MouseOver;
@@ -890,6 +874,7 @@ void NetworkDelegate::paint(QPainter *painter, const QStyleOptionViewItem &optio
         painter->setRenderHint(QPainter::Antialiasing, true);
 
         QRect rct = checkRect(option.rect);
+        painter->save();
         painter->setPen(QPen(Qt::NoPen));
         painter->setBrush(m_parentWidget->palette().color(QPalette::Highlight));
 
@@ -899,6 +884,7 @@ void NetworkDelegate::paint(QPainter *painter, const QStyleOptionViewItem &optio
         else
             drawCheck(painter, rct, pen, DIAMETER);
 
+        painter->restore();
         break;
     }
     case NetConnectionType::Connecting: {
@@ -936,7 +922,7 @@ bool NetworkDelegate::cantHover(const QModelIndex &index) const
     NetItemType itemType = index.data(TypeRole).value<NetItemType>();
     // 如果是无线网络或者连接隐藏网络项，且当前开启了飞行模式，则当前行不让点击
     if (itemType == NetItemType::WirelessViewItem || itemType == NetItemType::WirelessHiddenViewItem)
-        return (m_airplaneMode && m_airplaneMode->wifiEnabled());
+        return !(index.data(NetItemRole::AvailableRole).toBool());
 
     return (itemType == NetItemType::DeviceControllViewItem
             || itemType == NetItemType::WirelessControllViewItem
@@ -1031,7 +1017,7 @@ bool NetworkDelegate::switchIsEnabled(const QModelIndex &index) const
     case NetItemType::DeviceControllViewItem: {
         QList<NetworkDeviceBase *> devices = index.data(NetItemRole::DeviceDataRole).value<QList<NetworkDeviceBase *>>();
         for (NetworkDeviceBase *device : devices) {
-            if (device->isEnabled())
+            if (device->available() && device->isEnabled())
                 return true;
         }
         return false;
@@ -1045,7 +1031,7 @@ bool NetworkDelegate::switchIsEnabled(const QModelIndex &index) const
     case NetItemType::WirelessControllViewItem: {
         NetworkDeviceBase *device = index.data(NetItemRole::DeviceDataRole).value<NetworkDeviceBase *>();
         if (device)
-            return device->isEnabled() && !m_airplaneMode->wifiEnabled();
+            return device->isEnabled() && device->available();
         break;
     }
     default:
@@ -1063,7 +1049,7 @@ void NetworkDelegate::drawRefreshButton(QPainter *painter, const QStyleOptionVie
     QRect rctIcon(option.rect.width() - SWITCH_WIDTH - 36, option.rect.top() + (option.rect.height() - 20) / 2, 20, 20);
     QPixmap pixmap = DHiDPIHelper::loadNxPixmap(ThemeManager::instance()->getIcon("refresh"));
     painter->save();
-    painter->setRenderHint(QPainter::Antialiasing, true);
+    painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
     if (m_refreshAngle.contains(index)) {
         QPoint ptCenter(rctIcon.left() + rctIcon.width() / 2, rctIcon.top() + rctIcon.height() / 2);
         painter->translate(ptCenter);
@@ -1090,8 +1076,9 @@ void NetworkDelegate::drawSwitchButton(QPainter *painter, const QStyleOptionView
     bool isSwitchEnabled = switchIsEnabled(index);
     NetItemType itemType = index.data(TypeRole).value<NetItemType>();
     // 如果是总控、有线网卡、无线网卡开关，则需要显示开关
-    QPalette::ColorRole colorRole = isSwitchEnabled ? QPalette::ColorRole::Highlight : DPalette::ColorRole::ButtonText;
-    if (m_airplaneMode->wifiEnabled() && itemType == NetItemType::WirelessControllViewItem)
+    QPalette::ColorRole colorRole = isSwitchEnabled ? QPalette::ColorRole::Highlight : DPalette::ColorRole::WindowText;
+    if (!index.data(NetItemRole::AvailableRole).toBool() && (itemType == NetItemType::WirelessControllViewItem
+            || itemType == NetItemType::DeviceControllViewItem))
         painter->setBrush(palette.color(QPalette::ColorGroup::Disabled, colorRole));
     else
         painter->setBrush(palette.color(colorRole));
@@ -1120,7 +1107,7 @@ bool NetworkDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, cons
     case QEvent::MouseButtonPress: {
         QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
         if (index.data(TypeRole).value<NetItemType>() == NetItemType::WirelessControllViewItem) {
-            if (!m_airplaneMode->wifiEnabled()) {
+            if (index.data(NetItemRole::AvailableRole).toBool()) {
                 if (!m_refreshAngle.contains(index)) {
                     QRect rctSwitch(option.rect.width() - SWITCH_WIDTH - 36, option.rect.top() + (option.rect.height() - 20) / 2, 20, 20);
                     if (rctSwitch.contains(mouseEvent->pos())) {
@@ -1138,7 +1125,7 @@ bool NetworkDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, cons
             NetItemType itemType = index.data(TypeRole).value<NetItemType>();
             // 以下三种情况可以点击按钮
             // 1: 飞行模式关闭 2: 当前是有线网卡 3: 当前是有线网卡总控
-            if (!m_airplaneMode->wifiEnabled() || itemType == NetItemType::WiredControllViewItem
+            if (index.data(NetItemRole::AvailableRole).toBool() || itemType == NetItemType::WiredControllViewItem
                 || (itemType == NetItemType::DeviceControllViewItem && index.data(NetItemRole::DeviceTypeRole).value<DeviceType>() == DeviceType::Wired)) {
                 QRect rctSwitch(option.rect.width() - SWITCH_WIDTH - 10,
                                 option.rect.top() + (option.rect.height() - SWITCH_HEIGHT) / 2,
