@@ -45,9 +45,11 @@ protected Q_SLOT:
 
 protected:
     ThemeManager(QObject *parent = nullptr);
+    void setInputStyle(Dtk::Widget::DLineEdit *inputEdit);
 
 private:
     ThemeType m_themeType;
+    QList<QPointer<Dtk::Widget::DLineEdit>> m_editList;
 };
 
 #endif // THEMEMANAGER_H
