@@ -30,6 +30,7 @@
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/WirelessSecuritySetting>
 #include <NetworkManagerQt/WirelessSetting>
+#include <NetworkManagerQt/Security8021xSetting>
 
 #include <com_deepin_daemon_airplanemode.h>
 
@@ -513,6 +514,13 @@ bool NetworkPluginHelper::needSetPassword(AccessPoints *accessPoint) const
     case NetworkManager::WirelessSecuritySetting::KeyMgmt::Wep:
         psk = securitySetting->wepKey0();
         break;
+    case NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaEap: {
+        NetworkManager::Security8021xSetting::Ptr securitySetting =
+                settings->setting(NetworkManager::Setting::SettingType::Security8021x).dynamicCast<NetworkManager::Security8021xSetting>();
+        if (!securitySetting.isNull())
+            psk = securitySetting->password();
+        break;
+    }
     case NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaPsk:
     default:
         psk = securitySetting->psk();
