@@ -41,7 +41,6 @@ DCCNetworkModule::DCCNetworkModule()
     , ModuleInterface()
     , m_indexWidget(nullptr)
     , m_connEditPage(nullptr)
-    , m_airplaneMode(new DBusAirplaneMode("com.deepin.daemon.AirplaneMode", "/com/deepin/daemon/AirplaneMode", QDBusConnection::systemBus(), this))
     , m_dconfig(DConfig::create("org.deepin.dde.network", "org.deepin.dde.network", QString(), this))
 {
     QTranslator *translator = new QTranslator(this);
@@ -58,8 +57,10 @@ DCCNetworkModule::DCCNetworkModule()
 
 DCCNetworkModule::~DCCNetworkModule()
 {
-    if (m_indexWidget)
+    if (m_indexWidget) {
         m_indexWidget->deleteLater();
+        m_indexWidget = nullptr;
+    }
 }
 
 void DCCNetworkModule::preInitialize(bool sync, FrameProxyInterface::PushType)
@@ -106,7 +107,8 @@ void DCCNetworkModule::active()
     connect(m_indexWidget, &NetworkModuleWidget::requestShowProxyPage, this, &DCCNetworkModule::showProxyPage);
     connect(m_indexWidget, &NetworkModuleWidget::requestHotspotPage, this, &DCCNetworkModule::showHotspotPage);
     connect(m_indexWidget, &NetworkModuleWidget::requestShowInfomation, this, &DCCNetworkModule::showDetailPage);
-    connect(m_indexWidget, &NetworkModuleWidget::destroyed, [ this ] {
+    connect(m_indexWidget, &NetworkModuleWidget::destroyed, this, [ this ] {
+        m_indexWidget->deleteLater();
         m_indexWidget = nullptr;
     });
     connect(m_indexWidget, &NetworkModuleWidget::requestShowAirplanePage, this, &DCCNetworkModule::showAirplanePage);
@@ -701,8 +703,6 @@ void DCCNetworkModule::showDeviceDetailPage(NetworkDeviceBase *dev, const QStrin
             m_frameProxy->pushWidget(this, w, dccV20::FrameProxyInterface::PushType::CoverTop);
             wirelessPage->setVisible(true);
         });
-        connect(m_airplaneMode, &DBusAirplaneMode::WifiEnabledChanged, wirelessPage, &WirelessPage::onAirplaneModeChanged);
-        wirelessPage->onAirplaneModeChanged(m_airplaneMode->wifiEnabled());
 
         wirelessPage->jumpByUuid(searchPath);
     } else if (dev->deviceType() == DeviceType::Wired) {
@@ -744,11 +744,9 @@ void DCCNetworkModule::showProxyPage()
 void DCCNetworkModule::showHotspotPage(const QString &searchPath)
 {
     HotspotPage *hotspot = new HotspotPage();
-    hotspot->onAirplaneModeChanged(m_airplaneMode->wifiEnabled());
     connect(hotspot, &HotspotPage::requestNextPage, this, [ = ](ContentWidget * const w) {
         m_frameProxy->pushWidget(this, w, dccV20::FrameProxyInterface::PushType::CoverTop);
     });
-    connect(m_airplaneMode, &DBusAirplaneMode::WifiEnabledChanged, hotspot, &HotspotPage::onAirplaneModeChanged);
     m_frameProxy->pushWidget(this, hotspot);
     hotspot->jumpPath(searchPath);
 }
