@@ -4,8 +4,6 @@ if [ ! -d "translations/" ];then
 fi
 cd ./translations
 rm -f dcc-network-plugin.ts
-lupdate ../ ../../src -ts -no-ui-lines -locations none -no-obsolete dcc-network-plugin.ts
+lupdate ../ -ts -no-ui-lines -locations none -no-obsolete dcc-network-plugin.ts
 sed -e 's/DCC_NAMESPACE/dccV20/g' dcc-network-plugin.ts > tmp.ts
-mv tmp.ts dcc-network-plugin.ts
-cd ../
-tx push -s -b m20
+mv tmp.ts dcc-network-plugin.ts
\ No newline at end of file
