@@ -12,7 +12,6 @@
 #include "widgets/switchwidget.h"
 #include "widgets/comboxwidget.h"
 #include "window/utils.h"
-#include "widgets/passwdlineeditwidget.h"
 
 #include <DPalette>
 #include <DApplicationHelper>
@@ -42,6 +41,7 @@ ProxyPage::ProxyPage(QWidget *parent)
     : QWidget(parent)
     , m_autoWidget(new TranslucentFrame(this))
     , m_buttonTuple(new ButtonTuple(ButtonTuple::Save, this))
+    , m_dconfig(DConfig::create("org.deepin.dde.network", "org.deepin.dde.network", QString(), this))
 {
     ContentWidget *conentwidget = new ContentWidget(this);
     conentwidget->setAccessibleName("ProxyPage_ContentWidget");
@@ -70,7 +70,6 @@ ProxyPage::ProxyPage(QWidget *parent)
 
     // 手动代理编辑界面处理逻辑提取
     auto initProxyGroup = [ this ](LineEditWidget *&proxyEdit, LineEditWidget *&portEdit, const QString &proxyTitle, SettingsGroup *&group) {
-        group->setSpacing(1);
         proxyEdit = new LineEditWidget(group);
         proxyEdit->setPlaceholderText(tr("Optional"));
         proxyEdit->setTitle(proxyTitle);
@@ -90,51 +89,18 @@ ProxyPage::ProxyPage(QWidget *parent)
         });
     };
 
-    auto initAuthEditGroup = [ this ](SwitchWidget *&switchWidget, LineEditWidget *&userNameEdit, PasswdLineEditWidget *&passwordEdit, SettingsGroup *&group) {
-        switchWidget = new SwitchWidget(group);
-        switchWidget->setTitle(tr("Authentication is required"));
-        switchWidget->setChecked(false);
-        group->appendItem(switchWidget);
-
-        userNameEdit = new LineEditWidget(group);
-        userNameEdit->setTitle(tr("Username"));
-        userNameEdit->setPlaceholderText(tr("Required"));
-        userNameEdit->textEdit()->installEventFilter(this);
-        userNameEdit->setVisible(false);
-        group->appendItem(userNameEdit);
-
-        passwordEdit = new PasswdLineEditWidget(group);
-        passwordEdit->setTitle(tr("Password"));
-        passwordEdit->setPlaceholderText(tr("Required"));
-        passwordEdit->textEdit()->setEchoMode(QLineEdit::Password);
-        passwordEdit->textEdit()->installEventFilter(this);
-        passwordEdit->textEdit()->setValidator(new QRegExpValidator(QRegExp("^\\S+$"), this));
-        passwordEdit->setVisible(false);
-        group->appendItem(passwordEdit);
-
-        connect(switchWidget, &SwitchWidget::checkedChanged, this, [ = ](const bool checked) {
-            userNameEdit->setVisible(checked);
-            passwordEdit->setVisible(checked);
-            m_buttonTuple->setEnabled(true);
-        });
-    };
-
     //  手动代理编辑界面控件初始化
     SettingsGroup *httpGroup = new SettingsGroup(contentFrame);
     initProxyGroup(m_httpAddr, m_httpPort, tr("HTTP Proxy"), httpGroup);
-    initAuthEditGroup(m_httpAuthSwitch, m_httpUserName, m_httpPassword, httpGroup);
 
     SettingsGroup *httpsGroup = new SettingsGroup(contentFrame);
     initProxyGroup(m_httpsAddr, m_httpsPort, tr("HTTPS Proxy"), httpsGroup);
-    initAuthEditGroup(m_httpsAuthSwitch, m_httpsUserName, m_httpsPassword, httpsGroup);
 
     SettingsGroup *ftpGroup = new SettingsGroup(contentFrame);
     initProxyGroup(m_ftpAddr, m_ftpPort, tr("FTP Proxy"), ftpGroup);
-    initAuthEditGroup(m_ftpAuthSwitch, m_ftpUserName, m_ftpPassword, ftpGroup);
 
     SettingsGroup *socksGroup = new SettingsGroup(contentFrame);
     initProxyGroup(m_socksAddr, m_socksPort, tr("SOCKS Proxy"), socksGroup);
-    initAuthEditGroup(m_socksAuthSwitch, m_socksUserName, m_socksPassword, socksGroup);
 
     // 手动代理界面忽略主机编辑框初始化
     m_ignoreList = new DTextEdit(contentFrame);
@@ -159,20 +125,14 @@ ProxyPage::ProxyPage(QWidget *parent)
 
     // 手动代理界面布局
     QVBoxLayout *manualLayout = new QVBoxLayout(contentFrame);
-    manualLayout->setSpacing(0);
-    manualLayout->addSpacing(20);
     manualLayout->addWidget(httpGroup);
-    manualLayout->addSpacing(20);
     manualLayout->addWidget(httpsGroup);
-    manualLayout->addSpacing(20);
     manualLayout->addWidget(ftpGroup);
-    manualLayout->addSpacing(20);
     manualLayout->addWidget(socksGroup);
-    manualLayout->addSpacing(20);
     manualLayout->addWidget(m_ignoreList);
     manualLayout->addWidget(ignoreTips);
     manualLayout->setMargin(0);
-
+    manualLayout->setSpacing(10);
     m_manualWidget = new TranslucentFrame(contentFrame);
     m_manualWidget->setLayout(manualLayout);
     m_manualWidget->setVisible(false);
@@ -213,7 +173,6 @@ ProxyPage::ProxyPage(QWidget *parent)
     connect(proxyController, &ProxyController::proxyMethodChanged, this, &ProxyPage::onProxyMethodChanged);
     connect(proxyController, &ProxyController::proxyIgnoreHostsChanged, this, &ProxyPage::onIgnoreHostsChanged);
     connect(proxyController, &ProxyController::proxyChanged, this, &ProxyPage::onProxyChanged);
-    connect(proxyController, &ProxyController::proxyAuthChanged, this, &ProxyPage::onProxyAuthChanged);
     connect(proxyController, &ProxyController::autoProxyChanged, m_autoUrl, &LineEditWidget::setText);
 
     onProxyMethodChanged(proxyController->proxyMethod());
@@ -224,8 +183,8 @@ ProxyPage::ProxyPage(QWidget *parent)
     connect(m_proxySwitch, &SwitchWidget::checkedChanged, m_proxyTypeBox, [ = ](const bool checked) {
         m_buttonTuple->setEnabled(checked);
         if (checked) {
-            // 打开代理默认手动
-            onProxyMethodChanged(ProxyMethod::Manual);
+            // 根据最后设置的代理类型重置界面
+            onProxyMethodChanged(getProxyMethod());
         } else {
             // 关闭代理
             proxyController->setProxyMethod(ProxyMethod::None);
@@ -324,23 +283,19 @@ void ProxyPage::applySettings()
     if (!m_proxySwitch->checked()) {
         proxyController->setProxyMethod(ProxyMethod::None);
     } else if (m_proxyTypeBox->comboBox()->currentIndex() == ProxyMethodList.indexOf(MANUAL)) {
-        if (!checkValue()) {
-            return;
-        }
-
         proxyController->setProxy(SysProxyType::Http, m_httpAddr->text(), m_httpPort->text());
-        proxyController->setProxyAuth(SysProxyType::Http, m_httpUserName->text(), m_httpPassword->text(), m_httpAuthSwitch->checked());
         proxyController->setProxy(SysProxyType::Https, m_httpsAddr->text(), m_httpsPort->text());
-        proxyController->setProxyAuth(SysProxyType::Https, m_httpsUserName->text(), m_httpsPassword->text(), m_httpsAuthSwitch->checked());
         proxyController->setProxy(SysProxyType::Ftp, m_ftpAddr->text(), m_ftpPort->text());
-        proxyController->setProxyAuth(SysProxyType::Ftp, m_ftpUserName->text(), m_ftpPassword->text(), m_ftpAuthSwitch->checked());
         proxyController->setProxy(SysProxyType::Socks, m_socksAddr->text(), m_socksPort->text());
-        proxyController->setProxyAuth(SysProxyType::Socks, m_socksUserName->text(), m_socksPassword->text(), m_socksAuthSwitch->checked());
         proxyController->setProxyIgnoreHosts(m_ignoreList->toPlainText());
         proxyController->setProxyMethod(ProxyMethod::Manual);
+        // 保存上一次设置的代理类型
+        saveProxyMethod("manual");
     } else if (m_proxyTypeBox->comboBox()->currentIndex() == ProxyMethodList.indexOf(AUTO)) {
         proxyController->setAutoProxy(m_autoUrl->text());
         proxyController->setProxyMethod(ProxyMethod::Auto);
+        // 保存上一次设置的代理类型
+        saveProxyMethod("auto");
     }
 }
 
@@ -376,40 +331,6 @@ void ProxyPage::onProxyChanged(const SysProxyConfig &config)
     }
 }
 
-void ProxyPage::onProxyAuthChanged(const SysProxyConfig &config)
-{
-    switch (config.type) {
-    case SysProxyType::Http:
-        m_httpAuthSwitch->setChecked(config.enableAuth);
-        m_httpUserName->setText(config.userName);
-        m_httpPassword->setText(config.password);
-        m_httpUserName->setVisible(config.enableAuth);
-        m_httpPassword->setVisible(config.enableAuth);
-        break;
-    case SysProxyType::Https:
-        m_httpsAuthSwitch->setChecked(config.enableAuth);
-        m_httpsUserName->setText(config.userName);
-        m_httpsPassword->setText(config.password);
-        m_httpsUserName->setVisible(config.enableAuth);
-        m_httpsPassword->setVisible(config.enableAuth);
-        break;
-    case SysProxyType::Ftp:
-        m_ftpAuthSwitch->setChecked(config.enableAuth);
-        m_ftpUserName->setText(config.userName);
-        m_ftpPassword->setText(config.password);
-        m_ftpUserName->setVisible(config.enableAuth);
-        m_ftpPassword->setVisible(config.enableAuth);
-        break;
-    case SysProxyType::Socks:
-        m_socksAuthSwitch->setChecked(config.enableAuth);
-        m_socksUserName->setText(config.userName);
-        m_socksPassword->setText(config.password);
-        m_socksUserName->setVisible(config.enableAuth);
-        m_socksPassword->setVisible(config.enableAuth);
-        break;
-    }
-}
-
 bool ProxyPage::eventFilter(QObject *watched, QEvent *event)
 {
     // 实现鼠标点击编辑框，确定按钮激活，捕捉FocusIn消息，DTextEdit没有鼠标点击消息
@@ -452,99 +373,23 @@ void ProxyPage::clearLineEditWidgetFocus()
 
     if (m_ignoreList)
         m_ignoreList->clearFocus();
-
-    if (m_httpUserName && m_httpUserName->dTextEdit()) {
-        m_httpUserName->dTextEdit()->clearFocus();
-        m_httpUserName->clearFocus();
-    }
-
-    if (m_httpPassword && m_httpPassword->dTextEdit()) {
-        m_httpPassword->dTextEdit()->clearFocus();
-        m_httpPassword->clearFocus();
-    }
-
-    if (m_httpsUserName && m_httpsUserName->dTextEdit())
-        m_httpsUserName->clearFocus();
-
-    if (m_httpsPassword && m_httpsPassword->dTextEdit()) {
-        m_httpsPassword->dTextEdit()->clearFocus();
-        m_httpsPassword->clearFocus();
-    }
-
-    if (m_ftpUserName && m_ftpUserName->dTextEdit()) {
-        m_ftpUserName->dTextEdit()->clearFocus();
-        m_ftpUserName->clearFocus();
-    }
-
-    if (m_ftpPassword && m_ftpPassword->dTextEdit()) {
-        m_ftpPassword->dTextEdit()->clearFocus();
-        m_ftpPassword->clearFocus();
-    }
-
-    if (m_socksUserName && m_socksUserName->dTextEdit()) {
-        m_socksUserName->dTextEdit()->clearFocus();
-        m_socksUserName->clearFocus();
-    }
-
-    if (m_socksPassword && m_socksPassword->dTextEdit()) {
-        m_socksPassword->dTextEdit()->clearFocus();
-        m_socksPassword->clearFocus();
-    }
 }
 
-bool ProxyPage::checkValue()
+void ProxyPage::saveProxyMethod(const QString &method)
 {
-    if (m_httpAuthSwitch->checked()) {
-        if (m_httpUserName->text().isEmpty()) {
-            m_httpUserName->setIsErr(true);
-            m_httpUserName->dTextEdit()->setFocus();
-            return false;
-        }
-        if (m_httpPassword->text().isEmpty()) {
-            m_httpPassword->setIsErr(true);
-            m_httpPassword->dTextEdit()->setFocus();
-            return false;
-        }
+    if (m_dconfig && m_dconfig->isValid()) {
+        m_dconfig->setValue("lastProxyMethod", method);
     }
+}
 
-    if (m_httpsAuthSwitch->checked()) {
-        if (m_httpsUserName->text().isEmpty()) {
-            m_httpsUserName->setIsErr(true);
-            m_httpsUserName->dTextEdit()->setFocus();
-            return false;
-        }
-        if (m_httpsPassword->text().isEmpty()) {
-            m_httpsPassword->setIsErr(true);
-            m_httpsPassword->dTextEdit()->setFocus();
-            return false;
-        }
-    }
-
-    if (m_ftpAuthSwitch->checked()) {
-        if (m_ftpUserName->text().isEmpty()) {
-            m_ftpUserName->setIsErr(true);
-            m_ftpUserName->dTextEdit()->setFocus();
-            return false;
-        }
-        if (m_ftpPassword->text().isEmpty()) {
-            m_ftpPassword->setIsErr(true);
-            m_ftpPassword->dTextEdit()->setFocus();
-            return false;
-        }
-    }
+ProxyMethod ProxyPage::getProxyMethod()
+{
+    if (m_dconfig && m_dconfig->isValid()) {
+        const QString method = m_dconfig->value("lastProxyMethod", "manual").toString();
 
-    if (m_socksAuthSwitch->checked()) {
-        if (m_socksUserName->text().isEmpty()) {
-            m_socksUserName->setIsErr(true);
-            m_socksUserName->dTextEdit()->setFocus();
-            return false;
-        }
-        if (m_socksPassword->text().isEmpty()) {
-            m_socksPassword->setIsErr(true);
-            m_socksPassword->dTextEdit()->setFocus();
-            return false;
-        }
+        if (method == "auto")
+            return ProxyMethod::Auto;
     }
 
-    return true;
+    return ProxyMethod::Manual;
 }
