@@ -62,6 +62,14 @@ void DslPppoeSettings::initSections()
     m_settingSections.append(dnsSection);
     m_settingSections.append(m_etherNetSection);
     m_settingSections.append(pppSection);
+
+    // UBXC000934 默认设置为auto，导致DSL拨号上网连上后立即断开
+    auto ipv6Setting = m_connSettings->setting(Setting::Ipv6).staticCast<Ipv6Setting>();
+    qInfo() << Q_FUNC_INFO << " ipv6Setting.isNull : " << ipv6Setting.isNull();
+    if (!ipv6Setting.isNull()) {
+        ipv6Setting->setMethod(Ipv6Setting::Ignored);
+        ipv6Setting->setInitialized(true);
+    }
 }
 
 bool DslPppoeSettings::clearInterfaceName()
