@@ -98,6 +98,10 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
+    <message>
+        <source>Wireless Connection %1</source>
+        <translation>Wireless Connection %1</translation>
+    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE Connection %1</translation>
@@ -424,8 +428,8 @@
         <translation>General</translation>
     </message>
     <message>
-        <source>Name (SSID)</source>
-        <translation>Name (SSID)</translation>
+        <source>Name</source>
+        <translation>Name</translation>
     </message>
     <message>
         <source>Required</source>
@@ -442,10 +446,6 @@
         <source>The name already exists</source>
         <translation>The name already exists</translation>
     </message>
-    <message>
-        <source>Name (SSID)</source>
-        <translation>Name (SSID)</translation>
-    </message>
     <message>
         <source>Name</source>
         <translation>Name</translation>
@@ -842,22 +842,6 @@
         <source>Port</source>
         <translation>Port</translation>
     </message>
-    <message>
-        <source>Authentication is required</source>
-        <translation>Authentication is required</translation>
-    </message>
-    <message>
-        <source>Username</source>
-        <translation>Username</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Required</translation>
-    </message>
-    <message>
-        <source>Password</source>
-        <translation>Password</translation>
-    </message>
     <message>
         <source>HTTP Proxy</source>
         <translation>HTTP Proxy</translation>
@@ -1929,6 +1913,14 @@
         <source>Not Bind</source>
         <translation>Not Bind</translation>
     </message>
+    <message>
+        <source>SSID</source>
+        <translation>SSID</translation>
+    </message>
+    <message>
+        <source>Required</source>
+        <translation>Required</translation>
+    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Device MAC Addr</translation>
