@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="ms">
 <context>
     <name>ChainsProxyPage</name>
     <message>
@@ -98,6 +98,10 @@
         <source>Hotspot</source>
         <translation>Kawasan Khas</translation>
     </message>
+    <message>
+        <source>Wireless Connection %1</source>
+        <translation>Sambungan Tanpa Wayar %1</translation>
+    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Sambungan PPPoE %1</translation>
@@ -204,68 +208,64 @@
     <message>
         <source>Airplane Mode</source>
         <translation type="unfinished"/>
-        <extra-child_page>Airplane Mode</extra-child_page>
-        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
     </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Penyesuai Rangkaian Berwayar</translation>
-        <extra-child_page>Wired Network</extra-child_page>
         <extra-contents_path>/network/Wired Network</extra-contents_path>
+        <extra-child_page>Wired Network</extra-child_page>
     </message>
     <message>
         <source>Add Network Connection</source>
         <translation>Tambah Sambungan Rangkaian</translation>
-        <extra-child_page>Wired Network</extra-child_page>
         <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
+        <extra-child_page>Wired Network</extra-child_page>
     </message>
     <message>
         <source>Wireless Network Adapter</source>
         <translation>Penyesuai Rangkaian Tanpa Wayar</translation>
-        <extra-child_page>Wireless Network</extra-child_page>
         <extra-contents_path>/network/Wireless Network</extra-contents_path>
+        <extra-child_page>Wireless Network</extra-child_page>
     </message>
     <message>
         <source>Connect to hidden network</source>
         <translation>Sambung ke rangkaian tersembunyi</translation>
-        <extra-child_page>Wireless Network</extra-child_page>
         <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
+        <extra-child_page>Wireless Network</extra-child_page>
     </message>
     <message>
         <source>DSL</source>
         <translation>DSL</translation>
-        <extra-child_page_hide>DSL</extra-child_page_hide>
         <extra-contents_path>/network/DSL</extra-contents_path>
+        <extra-child_page_hide>DSL</extra-child_page_hide>
     </message>
     <message>
         <source>Create PPPoE Connection</source>
         <translation>Cipta Sambungan PPPoE</translation>
-        <extra-child_page>DSL</extra-child_page>
         <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
+        <extra-child_page>DSL</extra-child_page>
     </message>
     <message>
         <source>VPN Status</source>
         <translation>Status VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Create VPN</source>
         <translation>Cipta VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Import VPN</source>
         <translation>Import VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Proxy Type</source>
         <translation>Jenis Proksi</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
-        <extra-contents_path>/network/Application Proxy</extra-contents_path>
     </message>
     <message>
         <source>Configuration URL</source>
@@ -274,98 +274,98 @@
     <message>
         <source>IP Address</source>
         <translation>Alamat IP</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Port</source>
         <translation>Port</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Username</source>
         <translation>Nama Pengguna</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Password</source>
         <translation>Kata Laluan</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Hotspot</source>
         <translation>Kawasan Khas</translation>
-        <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
+        <extra-child_page>Personal Hotspot</extra-child_page>
     </message>
     <message>
         <source>Create Hotspot</source>
         <translation>Cipta Kawasan Khas</translation>
-        <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
+        <extra-child_page>Personal Hotspot</extra-child_page>
     </message>
     <message>
         <source>Interface</source>
         <translation>Antara Muka</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>MAC</source>
         <translation>MAC</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Band</source>
         <translation>Jalur</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>IPv4</source>
         <translation>IPv4</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Gateway</source>
         <translation>Get Laluan</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Primary DNS</source>
         <translation>DNS Utama</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Netmask</source>
         <translation>Topeng Rangkaian</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>IPv6</source>
         <translation>IPv6</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Prefix</source>
         <translation>Awalan</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Speed</source>
         <translation>Kelajuan</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
 </context>
 <context>
@@ -424,8 +424,8 @@
         <translation>Am</translation>
     </message>
     <message>
-        <source>Name (SSID)</source>
-        <translation type="unfinished"/>
+        <source>Name</source>
+        <translation>Nama</translation>
     </message>
     <message>
         <source>Required</source>
@@ -442,10 +442,6 @@
         <source>The name already exists</source>
         <translation>Nama sudah wujud</translation>
     </message>
-    <message>
-        <source>Name (SSID)</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Name</source>
         <translation>Nama</translation>
@@ -823,8 +819,8 @@
     <message>
         <source>Proxy Type</source>
         <translation>Jenis Proksi</translation>
-        <extra-child_page>System Proxy</extra-child_page>
         <extra-contents_path>/network/System Proxy</extra-contents_path>
+        <extra-child_page>System Proxy</extra-child_page>
     </message>
     <message>
         <source>Manual</source>
@@ -842,22 +838,6 @@
         <source>Port</source>
         <translation>Port</translation>
     </message>
-    <message>
-        <source>Authentication is required</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Username</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>HTTP Proxy</source>
         <translation>Proksi HTTP</translation>
@@ -881,8 +861,8 @@
     <message>
         <source>Configuration URL</source>
         <translation>Konfigurasi URL</translation>
-        <extra-child_page>System Proxy</extra-child_page>
         <extra-contents_path>/network/System Proxy</extra-contents_path>
+        <extra-child_page>System Proxy</extra-child_page>
     </message>
 </context>
 <context>
@@ -1915,8 +1895,8 @@
     <message>
         <source>Connect to hidden network</source>
         <translation>Sambung ke rangkaian tersembunyi</translation>
-        <extra-child_page>WirelessPage</extra-child_page>
         <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
+        <extra-child_page>WirelessPage</extra-child_page>
     </message>
 </context>
 <context>
@@ -1929,6 +1909,14 @@
         <source>Not Bind</source>
         <translation>Tidak Diikat</translation>
     </message>
+    <message>
+        <source>SSID</source>
+        <translation>SSID</translation>
+    </message>
+    <message>
+        <source>Required</source>
+        <translation>Diperlukan</translation>
+    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Alamat MAC Peranti</translation>
@@ -1942,137 +1930,4 @@
         <translation>MTU</translation>
     </message>
 </context>
-<context>
-    <name>dde::network::NetworkDetails</name>
-    <message>
-        <source>Hotspot</source>
-        <translation>Kawasan Khas</translation>
-    </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Protocol</source>
-        <translation>Protokol</translation>
-    </message>
-    <message>
-        <source>Security Type</source>
-        <translation>Jenis Keselamatan</translation>
-    </message>
-    <message>
-        <source>Channel</source>
-        <translation>Saluran</translation>
-    </message>
-    <message>
-        <source>Band</source>
-        <translation>Jalur</translation>
-    </message>
-    <message>
-        <source>Interface</source>
-        <translation>Antara Muka</translation>
-    </message>
-    <message>
-        <source>MAC</source>
-        <translation>MAC</translation>
-    </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>Netmask</source>
-        <translation>Topeng Rangkaian</translation>
-    </message>
-    <message>
-        <source>Gateway</source>
-        <translation>Get Laluan</translation>
-    </message>
-    <message>
-        <source>Primary DNS</source>
-        <translation>DNS Utama</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Prefix</source>
-        <translation>Awalan</translation>
-    </message>
-    <message>
-        <source>Speed</source>
-        <translation>Kelajuan</translation>
-    </message>
-</context>
-<context>
-    <name>dde::network::NetworkDeviceRealize</name>
-    <message>
-        <source>Device disabled</source>
-        <translation>Peranti dilumpuhkan</translation>
-    </message>
-    <message>
-        <source>Connected but no Internet access</source>
-        <translation>Bersambung tetapi tiada capaian Internet</translation>
-    </message>
-    <message>
-        <source>Not connected</source>
-        <translation>Tidak bersambung</translation>
-    </message>
-    <message>
-        <source>Network cable unplugged</source>
-        <translation>Kabel rangkaian telah dicabut</translation>
-    </message>
-    <message>
-        <source>Connecting</source>
-        <translation>Menyambung</translation>
-    </message>
-    <message>
-        <source>Authenticating</source>
-        <translation>Mengesahihkan</translation>
-    </message>
-    <message>
-        <source>Obtaining IP address</source>
-        <translation>Mendapatkan alamat IP</translation>
-    </message>
-    <message>
-        <source>Connected</source>
-        <translation>Bersambung</translation>
-    </message>
-    <message>
-        <source>Disconnected</source>
-        <translation>Terputus</translation>
-    </message>
-    <message>
-        <source>IP conflict</source>
-        <translation>IP berkonflik</translation>
-    </message>
-    <message>
-        <source>Failed</source>
-        <translation>Gagal</translation>
-    </message>
-    <message>
-        <source>Obtaining address</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>dde::network::NetworkProcesser</name>
-    <message>
-        <source>Wired Network</source>
-        <translation>Rangkaian Berwayar</translation>
-    </message>
-    <message>
-        <source>Wired Network %1</source>
-        <translation>Rangkaian Berwayar %1</translation>
-    </message>
-    <message>
-        <source>Wireless Network</source>
-        <translation>Rangkaian Tanpa Wayar</translation>
-    </message>
-    <message>
-        <source>Wireless Network %1</source>
-        <translation>Sambungan Tanpa Wayar %1</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
