@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="pl">
 <context>
     <name>ChainsProxyPage</name>
     <message>
@@ -7,7 +7,7 @@
     </message>
     <message>
         <source>Proxy Type</source>
-        <translation>Typ Proxy</translation>
+        <translation>Typ proxy</translation>
     </message>
     <message>
         <source>IP Address</source>
@@ -98,6 +98,10 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
+    <message>
+        <source>Wireless Connection %1</source>
+        <translation>Połączenie bezprzewodowe %1</translation>
+    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Połączenie PPPoE %1</translation>
@@ -204,68 +208,64 @@
     <message>
         <source>Airplane Mode</source>
         <translation>Tryb samolotowy</translation>
-        <extra-child_page>Airplane Mode</extra-child_page>
-        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
     </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Przewodowa karta sieciowa</translation>
-        <extra-child_page>Wired Network</extra-child_page>
         <extra-contents_path>/network/Wired Network</extra-contents_path>
+        <extra-child_page>Wired Network</extra-child_page>
     </message>
     <message>
         <source>Add Network Connection</source>
         <translation>Dodaj Połączenie Sieciowe</translation>
-        <extra-child_page>Wired Network</extra-child_page>
         <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
+        <extra-child_page>Wired Network</extra-child_page>
     </message>
     <message>
         <source>Wireless Network Adapter</source>
         <translation>Bezprzewodowa karta sieciowa</translation>
-        <extra-child_page>Wireless Network</extra-child_page>
         <extra-contents_path>/network/Wireless Network</extra-contents_path>
+        <extra-child_page>Wireless Network</extra-child_page>
     </message>
     <message>
         <source>Connect to hidden network</source>
         <translation>Połącz z siecią ukrytą</translation>
-        <extra-child_page>Wireless Network</extra-child_page>
         <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
+        <extra-child_page>Wireless Network</extra-child_page>
     </message>
     <message>
         <source>DSL</source>
         <translation>DSL</translation>
-        <extra-child_page_hide>DSL</extra-child_page_hide>
         <extra-contents_path>/network/DSL</extra-contents_path>
+        <extra-child_page_hide>DSL</extra-child_page_hide>
     </message>
     <message>
         <source>Create PPPoE Connection</source>
         <translation>Utwórz połączenie PPPoE</translation>
-        <extra-child_page>DSL</extra-child_page>
         <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
+        <extra-child_page>DSL</extra-child_page>
     </message>
     <message>
         <source>VPN Status</source>
         <translation>Status VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Create VPN</source>
         <translation>Utwórz VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Import VPN</source>
         <translation>Importuj VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Proxy Type</source>
-        <translation>Typ Proxy</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
-        <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <translation>Typ proxy</translation>
     </message>
     <message>
         <source>Configuration URL</source>
@@ -274,98 +274,98 @@
     <message>
         <source>IP Address</source>
         <translation>Adres IP</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Port</source>
         <translation>Port</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Username</source>
         <translation>Nazwa użytkownika</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Password</source>
         <translation>Hasło</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Hotspot</source>
         <translation>Hotspot</translation>
-        <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
+        <extra-child_page>Personal Hotspot</extra-child_page>
     </message>
     <message>
         <source>Create Hotspot</source>
         <translation>Utwórz Hotspot</translation>
-        <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
+        <extra-child_page>Personal Hotspot</extra-child_page>
     </message>
     <message>
         <source>Interface</source>
         <translation>Interfejs</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>MAC</source>
         <translation>MAC</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Band</source>
         <translation>Pasmo</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>IPv4</source>
         <translation>IPv4</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Gateway</source>
         <translation>Brama sieciowa</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Primary DNS</source>
         <translation>Podstawowy DNS</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Netmask</source>
         <translation>Maska sieci</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>IPv6</source>
         <translation>IPv6</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Prefix</source>
         <translation>Prefiks</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Speed</source>
         <translation>Prędkość</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
 </context>
 <context>
@@ -424,8 +424,8 @@
         <translation>Ogólne</translation>
     </message>
     <message>
-        <source>Name (SSID)</source>
-        <translation type="unfinished"/>
+        <source>Name</source>
+        <translation>Nazwa</translation>
     </message>
     <message>
         <source>Required</source>
@@ -442,10 +442,6 @@
         <source>The name already exists</source>
         <translation>Taka nazwa już istnieje</translation>
     </message>
-    <message>
-        <source>Name (SSID)</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Name</source>
         <translation>Nazwa</translation>
@@ -822,9 +818,9 @@
     </message>
     <message>
         <source>Proxy Type</source>
-        <translation>Typ Proxy</translation>
-        <extra-child_page>System Proxy</extra-child_page>
+        <translation>Typ proxy</translation>
         <extra-contents_path>/network/System Proxy</extra-contents_path>
+        <extra-child_page>System Proxy</extra-child_page>
     </message>
     <message>
         <source>Manual</source>
@@ -842,22 +838,6 @@
         <source>Port</source>
         <translation>Port</translation>
     </message>
-    <message>
-        <source>Authentication is required</source>
-        <translation>Wymagane jest uwierzytelnienie</translation>
-    </message>
-    <message>
-        <source>Username</source>
-        <translation>Nazwa użytkownika</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>Wymagane</translation>
-    </message>
-    <message>
-        <source>Password</source>
-        <translation>Hasło</translation>
-    </message>
     <message>
         <source>HTTP Proxy</source>
         <translation>HTTP Proxy</translation>
@@ -881,8 +861,8 @@
     <message>
         <source>Configuration URL</source>
         <translation>Adres URL konfiguracji</translation>
-        <extra-child_page>System Proxy</extra-child_page>
         <extra-contents_path>/network/System Proxy</extra-contents_path>
+        <extra-child_page>System Proxy</extra-child_page>
     </message>
 </context>
 <context>
@@ -1330,7 +1310,7 @@
     </message>
     <message>
         <source>Allow Cisco Secure Desktop Trojan</source>
-        <translation>Pozwól na pulpitowego trojana bezpieczeństwa Cisco</translation>
+        <translation>Zezwól na trojana Cisco Secure Desktop</translation>
     </message>
     <message>
         <source>CSD Script</source>
@@ -1562,7 +1542,7 @@
     </message>
     <message>
         <source>Proxy Type</source>
-        <translation>Typ Proxy</translation>
+        <translation>Typ proxy</translation>
     </message>
     <message>
         <source>Server IP</source>
@@ -1915,8 +1895,8 @@
     <message>
         <source>Connect to hidden network</source>
         <translation>Połącz z siecią ukrytą</translation>
-        <extra-child_page>WirelessPage</extra-child_page>
         <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
+        <extra-child_page>WirelessPage</extra-child_page>
     </message>
 </context>
 <context>
@@ -1929,6 +1909,14 @@
         <source>Not Bind</source>
         <translation>Nie znaleziono</translation>
     </message>
+    <message>
+        <source>SSID</source>
+        <translation>SSID</translation>
+    </message>
+    <message>
+        <source>Required</source>
+        <translation>Wymagane</translation>
+    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Adres MAC urządzenia</translation>
@@ -1942,137 +1930,4 @@
         <translation>MTU</translation>
     </message>
 </context>
-<context>
-    <name>dde::network::NetworkDetails</name>
-    <message>
-        <source>Hotspot</source>
-        <translation>Hotspot</translation>
-    </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Protocol</source>
-        <translation>Protokół</translation>
-    </message>
-    <message>
-        <source>Security Type</source>
-        <translation>Typ zabezpieczenia</translation>
-    </message>
-    <message>
-        <source>Channel</source>
-        <translation>Kanał</translation>
-    </message>
-    <message>
-        <source>Band</source>
-        <translation>Pasmo</translation>
-    </message>
-    <message>
-        <source>Interface</source>
-        <translation>Interfejs</translation>
-    </message>
-    <message>
-        <source>MAC</source>
-        <translation>MAC</translation>
-    </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>Netmask</source>
-        <translation>Maska sieci</translation>
-    </message>
-    <message>
-        <source>Gateway</source>
-        <translation>Brama</translation>
-    </message>
-    <message>
-        <source>Primary DNS</source>
-        <translation>Podstawowy DNS</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Prefix</source>
-        <translation>Prefiks</translation>
-    </message>
-    <message>
-        <source>Speed</source>
-        <translation>Prędkość</translation>
-    </message>
-</context>
-<context>
-    <name>dde::network::NetworkDeviceRealize</name>
-    <message>
-        <source>Device disabled</source>
-        <translation>Urządzenie wyłączone</translation>
-    </message>
-    <message>
-        <source>Connected but no Internet access</source>
-        <translation>Połączono, brak dostępu do Internetu</translation>
-    </message>
-    <message>
-        <source>Not connected</source>
-        <translation>Nie połączono</translation>
-    </message>
-    <message>
-        <source>Network cable unplugged</source>
-        <translation>Kabel sieciowy odłączony</translation>
-    </message>
-    <message>
-        <source>Connecting</source>
-        <translation>Łączenie</translation>
-    </message>
-    <message>
-        <source>Authenticating</source>
-        <translation>Uwierzytelnianie</translation>
-    </message>
-    <message>
-        <source>Obtaining IP address</source>
-        <translation>Uzyskiwanie adresu IP</translation>
-    </message>
-    <message>
-        <source>Connected</source>
-        <translation>Połączono</translation>
-    </message>
-    <message>
-        <source>Disconnected</source>
-        <translation>Rozłączono</translation>
-    </message>
-    <message>
-        <source>IP conflict</source>
-        <translation>Konflikt IP</translation>
-    </message>
-    <message>
-        <source>Failed</source>
-        <translation>Wystąpił błąd</translation>
-    </message>
-    <message>
-        <source>Obtaining address</source>
-        <translation>Uzyskiwanie adresu</translation>
-    </message>
-</context>
-<context>
-    <name>dde::network::NetworkProcesser</name>
-    <message>
-        <source>Wired Network</source>
-        <translation>Połączenie przewodowe</translation>
-    </message>
-    <message>
-        <source>Wired Network %1</source>
-        <translation>Połączenie przewodowe %1</translation>
-    </message>
-    <message>
-        <source>Wireless Network</source>
-        <translation>Połączenie bezprzewodowe</translation>
-    </message>
-    <message>
-        <source>Wireless Network %1</source>
-        <translation>Połączenie bezprzewodowe %1</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
