@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="pt_BR">
 <context>
     <name>ChainsProxyPage</name>
     <message>
@@ -98,6 +98,10 @@
         <source>Hotspot</source>
         <translation>Hotspot</translation>
     </message>
+    <message>
+        <source>Wireless Connection %1</source>
+        <translation>Conexão Wi-Fi %1</translation>
+    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>Conexão PPPoE %1</translation>
@@ -183,7 +187,7 @@
     </message>
     <message>
         <source>Network Details</source>
-        <translation>Detalhes da Rede</translation>
+        <translation>Detalhes da Conexão de Rede</translation>
     </message>
     <message>
         <source>System Proxy</source>
@@ -204,68 +208,64 @@
     <message>
         <source>Airplane Mode</source>
         <translation>Modo Avião</translation>
-        <extra-child_page>Airplane Mode</extra-child_page>
-        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
     </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Placa de Rede Cabeada</translation>
-        <extra-child_page>Wired Network</extra-child_page>
         <extra-contents_path>/network/Wired Network</extra-contents_path>
+        <extra-child_page>Wired Network</extra-child_page>
     </message>
     <message>
         <source>Add Network Connection</source>
         <translation>Adicionar Conexão de Rede</translation>
-        <extra-child_page>Wired Network</extra-child_page>
         <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
+        <extra-child_page>Wired Network</extra-child_page>
     </message>
     <message>
         <source>Wireless Network Adapter</source>
         <translation>Placa de Rede Wi-Fi</translation>
-        <extra-child_page>Wireless Network</extra-child_page>
         <extra-contents_path>/network/Wireless Network</extra-contents_path>
+        <extra-child_page>Wireless Network</extra-child_page>
     </message>
     <message>
         <source>Connect to hidden network</source>
         <translation>Conectar-se à rede oculta</translation>
-        <extra-child_page>Wireless Network</extra-child_page>
         <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
+        <extra-child_page>Wireless Network</extra-child_page>
     </message>
     <message>
         <source>DSL</source>
         <translation>DSL</translation>
-        <extra-child_page_hide>DSL</extra-child_page_hide>
         <extra-contents_path>/network/DSL</extra-contents_path>
+        <extra-child_page_hide>DSL</extra-child_page_hide>
     </message>
     <message>
         <source>Create PPPoE Connection</source>
         <translation>Criar Conexão PPPoE</translation>
-        <extra-child_page>DSL</extra-child_page>
         <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
+        <extra-child_page>DSL</extra-child_page>
     </message>
     <message>
         <source>VPN Status</source>
         <translation>Status da VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Create VPN</source>
         <translation>Criar VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Import VPN</source>
         <translation>Importar VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Proxy Type</source>
         <translation>Tipo de Proxy</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
-        <extra-contents_path>/network/Application Proxy</extra-contents_path>
     </message>
     <message>
         <source>Configuration URL</source>
@@ -274,98 +274,98 @@
     <message>
         <source>IP Address</source>
         <translation>Endereço de IP</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Port</source>
         <translation>Porta</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Username</source>
         <translation>Nome de Usuário</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Password</source>
         <translation>Senha</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Hotspot</source>
         <translation>Hotspot</translation>
-        <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
+        <extra-child_page>Personal Hotspot</extra-child_page>
     </message>
     <message>
         <source>Create Hotspot</source>
         <translation>Criar Hotspot</translation>
-        <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
+        <extra-child_page>Personal Hotspot</extra-child_page>
     </message>
     <message>
         <source>Interface</source>
         <translation>Interface</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>MAC</source>
         <translation>MAC</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Band</source>
         <translation>Frequência</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>IPv4</source>
         <translation>IPv4</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Gateway</source>
         <translation>Gateway</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Primary DNS</source>
         <translation>DNS Primário</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Netmask</source>
         <translation>Máscara de Sub-rede</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>IPv6</source>
         <translation>IPv6</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Prefix</source>
         <translation>Prefixo</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Speed</source>
         <translation>Velocidade</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
 </context>
 <context>
@@ -424,8 +424,8 @@
         <translation>Geral</translation>
     </message>
     <message>
-        <source>Name (SSID)</source>
-        <translation type="unfinished"/>
+        <source>Name</source>
+        <translation>Nome</translation>
     </message>
     <message>
         <source>Required</source>
@@ -442,10 +442,6 @@
         <source>The name already exists</source>
         <translation>O nome já existe</translation>
     </message>
-    <message>
-        <source>Name (SSID)</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Name</source>
         <translation>Nome</translation>
@@ -648,7 +644,7 @@
     <name>NetworkDetailPage</name>
     <message>
         <source>Network Details</source>
-        <translation>Detalhes de Rede</translation>
+        <translation>Detalhes da Conexão de Rede</translation>
     </message>
 </context>
 <context>
@@ -676,7 +672,7 @@
     </message>
     <message>
         <source>Network Details</source>
-        <translation>Detalhes de Rede</translation>
+        <translation>Detalhes da Conexão de Rede</translation>
     </message>
     <message>
         <source>Network</source>
@@ -823,8 +819,8 @@
     <message>
         <source>Proxy Type</source>
         <translation>Tipo de Proxy</translation>
-        <extra-child_page>System Proxy</extra-child_page>
         <extra-contents_path>/network/System Proxy</extra-contents_path>
+        <extra-child_page>System Proxy</extra-child_page>
     </message>
     <message>
         <source>Manual</source>
@@ -842,22 +838,6 @@
         <source>Port</source>
         <translation>Porta</translation>
     </message>
-    <message>
-        <source>Authentication is required</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Username</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>HTTP Proxy</source>
         <translation>Proxy HTTP</translation>
@@ -881,8 +861,8 @@
     <message>
         <source>Configuration URL</source>
         <translation>URL de configuração</translation>
-        <extra-child_page>System Proxy</extra-child_page>
         <extra-contents_path>/network/System Proxy</extra-contents_path>
+        <extra-child_page>System Proxy</extra-child_page>
     </message>
 </context>
 <context>
@@ -1915,8 +1895,8 @@
     <message>
         <source>Connect to hidden network</source>
         <translation>Conectar-se à rede oculta</translation>
-        <extra-child_page>WirelessPage</extra-child_page>
         <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
+        <extra-child_page>WirelessPage</extra-child_page>
     </message>
 </context>
 <context>
@@ -1929,6 +1909,14 @@
         <source>Not Bind</source>
         <translation>Não Vincular</translation>
     </message>
+    <message>
+        <source>SSID</source>
+        <translation>SSID</translation>
+    </message>
+    <message>
+        <source>Required</source>
+        <translation>Obrigatório</translation>
+    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>Endereço MAC do Dispositivo</translation>
@@ -1942,137 +1930,4 @@
         <translation>MTU</translation>
     </message>
 </context>
-<context>
-    <name>dde::network::NetworkDetails</name>
-    <message>
-        <source>Hotspot</source>
-        <translation>Hotspot</translation>
-    </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Protocol</source>
-        <translation>Protocolo</translation>
-    </message>
-    <message>
-        <source>Security Type</source>
-        <translation>Tipo de Segurança</translation>
-    </message>
-    <message>
-        <source>Channel</source>
-        <translation>Canal</translation>
-    </message>
-    <message>
-        <source>Band</source>
-        <translation>Frequência</translation>
-    </message>
-    <message>
-        <source>Interface</source>
-        <translation>Interface</translation>
-    </message>
-    <message>
-        <source>MAC</source>
-        <translation>MAC</translation>
-    </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>Netmask</source>
-        <translation>Máscara de Sub-rede</translation>
-    </message>
-    <message>
-        <source>Gateway</source>
-        <translation>Gateway</translation>
-    </message>
-    <message>
-        <source>Primary DNS</source>
-        <translation>DNS Primário</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Prefix</source>
-        <translation>Prefixo</translation>
-    </message>
-    <message>
-        <source>Speed</source>
-        <translation>Velocidade</translation>
-    </message>
-</context>
-<context>
-    <name>dde::network::NetworkDeviceRealize</name>
-    <message>
-        <source>Device disabled</source>
-        <translation>Dispositivo desabilitado</translation>
-    </message>
-    <message>
-        <source>Connected but no Internet access</source>
-        <translation>Conectado, sem internet</translation>
-    </message>
-    <message>
-        <source>Not connected</source>
-        <translation>Não conectado</translation>
-    </message>
-    <message>
-        <source>Network cable unplugged</source>
-        <translation>Cabo de rede desconectado</translation>
-    </message>
-    <message>
-        <source>Connecting</source>
-        <translation>Conectando</translation>
-    </message>
-    <message>
-        <source>Authenticating</source>
-        <translation>Autenticando</translation>
-    </message>
-    <message>
-        <source>Obtaining IP address</source>
-        <translation>Obtendo endereço IP</translation>
-    </message>
-    <message>
-        <source>Connected</source>
-        <translation>Conectado</translation>
-    </message>
-    <message>
-        <source>Disconnected</source>
-        <translation>Desconectado</translation>
-    </message>
-    <message>
-        <source>IP conflict</source>
-        <translation>Conflito de IP</translation>
-    </message>
-    <message>
-        <source>Failed</source>
-        <translation>Falhou</translation>
-    </message>
-    <message>
-        <source>Obtaining address</source>
-        <translation>Obtendo endereço</translation>
-    </message>
-</context>
-<context>
-    <name>dde::network::NetworkProcesser</name>
-    <message>
-        <source>Wired Network</source>
-        <translation>Rede Cabeada</translation>
-    </message>
-    <message>
-        <source>Wired Network %1</source>
-        <translation>Rede Cabeada %1</translation>
-    </message>
-    <message>
-        <source>Wireless Network</source>
-        <translation>Rede Wi-Fi</translation>
-    </message>
-    <message>
-        <source>Wireless Network %1</source>
-        <translation>Rede Wi-Fi %1</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
