@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="zh_TW">
 <context>
     <name>ChainsProxyPage</name>
     <message>
@@ -98,6 +98,10 @@
         <source>Hotspot</source>
         <translation>無線熱點</translation>
     </message>
+    <message>
+        <source>Wireless Connection %1</source>
+        <translation>無線連接 %1</translation>
+    </message>
     <message>
         <source>PPPoE Connection %1</source>
         <translation>PPPoE 連線 %1</translation>
@@ -204,68 +208,64 @@
     <message>
         <source>Airplane Mode</source>
         <translation>飛航模式</translation>
-        <extra-child_page>Airplane Mode</extra-child_page>
-        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
     </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>有線網路介面卡</translation>
-        <extra-child_page>Wired Network</extra-child_page>
         <extra-contents_path>/network/Wired Network</extra-contents_path>
+        <extra-child_page>Wired Network</extra-child_page>
     </message>
     <message>
         <source>Add Network Connection</source>
         <translation>新增網路連線</translation>
-        <extra-child_page>Wired Network</extra-child_page>
         <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
+        <extra-child_page>Wired Network</extra-child_page>
     </message>
     <message>
         <source>Wireless Network Adapter</source>
         <translation>無線網路介面卡</translation>
-        <extra-child_page>Wireless Network</extra-child_page>
         <extra-contents_path>/network/Wireless Network</extra-contents_path>
+        <extra-child_page>Wireless Network</extra-child_page>
     </message>
     <message>
         <source>Connect to hidden network</source>
         <translation>連線到隱藏網路</translation>
-        <extra-child_page>Wireless Network</extra-child_page>
         <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
+        <extra-child_page>Wireless Network</extra-child_page>
     </message>
     <message>
         <source>DSL</source>
         <translation>DSL</translation>
-        <extra-child_page_hide>DSL</extra-child_page_hide>
         <extra-contents_path>/network/DSL</extra-contents_path>
+        <extra-child_page_hide>DSL</extra-child_page_hide>
     </message>
     <message>
         <source>Create PPPoE Connection</source>
         <translation>建立 PPPoE 連線</translation>
-        <extra-child_page>DSL</extra-child_page>
         <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
+        <extra-child_page>DSL</extra-child_page>
     </message>
     <message>
         <source>VPN Status</source>
         <translation>VPN 狀態</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Create VPN</source>
         <translation>建立 VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Import VPN</source>
         <translation>加入 VPN</translation>
-        <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
+        <extra-child_page>VPN</extra-child_page>
     </message>
     <message>
         <source>Proxy Type</source>
         <translation>代理伺服器類型</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
-        <extra-contents_path>/network/Application Proxy</extra-contents_path>
     </message>
     <message>
         <source>Configuration URL</source>
@@ -274,98 +274,98 @@
     <message>
         <source>IP Address</source>
         <translation>IP 位址</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Port</source>
         <translation>連線埠</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Username</source>
         <translation>使用者名稱</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Password</source>
         <translation>密碼</translation>
-        <extra-child_page>Application Proxy</extra-child_page>
         <extra-contents_path>/network/Application Proxy</extra-contents_path>
+        <extra-child_page>Application Proxy</extra-child_page>
     </message>
     <message>
         <source>Hotspot</source>
         <translation>無線熱點</translation>
-        <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
+        <extra-child_page>Personal Hotspot</extra-child_page>
     </message>
     <message>
         <source>Create Hotspot</source>
         <translation>建立熱點</translation>
-        <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
+        <extra-child_page>Personal Hotspot</extra-child_page>
     </message>
     <message>
         <source>Interface</source>
         <translation>界面</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>MAC</source>
         <translation>MAC 位址</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Band</source>
         <translation>頻段</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>IPv4</source>
         <translation>IPv4</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Gateway</source>
         <translation>閘道器</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Primary DNS</source>
         <translation>主要 DNS</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Netmask</source>
         <translation>子網路遮罩</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>IPv6</source>
         <translation>IPv6</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Prefix</source>
         <translation>前置詞</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
     <message>
         <source>Speed</source>
         <translation>速度</translation>
-        <extra-child_page>Network Details</extra-child_page>
         <extra-contents_path>/network/Network Details</extra-contents_path>
+        <extra-child_page>Network Details</extra-child_page>
     </message>
 </context>
 <context>
@@ -424,8 +424,8 @@
         <translation>一般</translation>
     </message>
     <message>
-        <source>Name (SSID)</source>
-        <translation>名稱（SSID）</translation>
+        <source>Name</source>
+        <translation>名稱</translation>
     </message>
     <message>
         <source>Required</source>
@@ -442,10 +442,6 @@
         <source>The name already exists</source>
         <translation>名稱已存在</translation>
     </message>
-    <message>
-        <source>Name (SSID)</source>
-        <translation>名稱（SSID）</translation>
-    </message>
     <message>
         <source>Name</source>
         <translation>名稱</translation>
@@ -823,8 +819,8 @@
     <message>
         <source>Proxy Type</source>
         <translation>代理類型</translation>
-        <extra-child_page>System Proxy</extra-child_page>
         <extra-contents_path>/network/System Proxy</extra-contents_path>
+        <extra-child_page>System Proxy</extra-child_page>
     </message>
     <message>
         <source>Manual</source>
@@ -842,22 +838,6 @@
         <source>Port</source>
         <translation>連線埠</translation>
     </message>
-    <message>
-        <source>Authentication is required</source>
-        <translation>需要認證</translation>
-    </message>
-    <message>
-        <source>Username</source>
-        <translation>使用者名稱</translation>
-    </message>
-    <message>
-        <source>Required</source>
-        <translation>必填</translation>
-    </message>
-    <message>
-        <source>Password</source>
-        <translation>密碼</translation>
-    </message>
     <message>
         <source>HTTP Proxy</source>
         <translation>HTTP 代理伺服器</translation>
@@ -881,8 +861,8 @@
     <message>
         <source>Configuration URL</source>
         <translation>設定 URL</translation>
-        <extra-child_page>System Proxy</extra-child_page>
         <extra-contents_path>/network/System Proxy</extra-contents_path>
+        <extra-child_page>System Proxy</extra-child_page>
     </message>
 </context>
 <context>
@@ -1915,8 +1895,8 @@
     <message>
         <source>Connect to hidden network</source>
         <translation>連線到隱藏網路</translation>
-        <extra-child_page>WirelessPage</extra-child_page>
         <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
+        <extra-child_page>WirelessPage</extra-child_page>
     </message>
 </context>
 <context>
@@ -1929,6 +1909,14 @@
         <source>Not Bind</source>
         <translation>未連結</translation>
     </message>
+    <message>
+        <source>SSID</source>
+        <translation>SSID</translation>
+    </message>
+    <message>
+        <source>Required</source>
+        <translation>必填</translation>
+    </message>
     <message>
         <source>Device MAC Addr</source>
         <translation>裝置 MAC 位址</translation>
@@ -1942,137 +1930,4 @@
         <translation>MTU</translation>
     </message>
 </context>
-<context>
-    <name>dde::network::NetworkDetails</name>
-    <message>
-        <source>Hotspot</source>
-        <translation>無線熱點</translation>
-    </message>
-    <message>
-        <source>SSID</source>
-        <translation>SSID</translation>
-    </message>
-    <message>
-        <source>Protocol</source>
-        <translation>協議</translation>
-    </message>
-    <message>
-        <source>Security Type</source>
-        <translation>安全類型</translation>
-    </message>
-    <message>
-        <source>Channel</source>
-        <translation>聲道</translation>
-    </message>
-    <message>
-        <source>Band</source>
-        <translation>頻段</translation>
-    </message>
-    <message>
-        <source>Interface</source>
-        <translation>界面</translation>
-    </message>
-    <message>
-        <source>MAC</source>
-        <translation>MAC 位址</translation>
-    </message>
-    <message>
-        <source>IPv4</source>
-        <translation>IPv4</translation>
-    </message>
-    <message>
-        <source>Netmask</source>
-        <translation>子網路遮罩</translation>
-    </message>
-    <message>
-        <source>Gateway</source>
-        <translation>閘道器</translation>
-    </message>
-    <message>
-        <source>Primary DNS</source>
-        <translation>主要 DNS</translation>
-    </message>
-    <message>
-        <source>IPv6</source>
-        <translation>IPv6</translation>
-    </message>
-    <message>
-        <source>Prefix</source>
-        <translation>前置詞</translation>
-    </message>
-    <message>
-        <source>Speed</source>
-        <translation>速度</translation>
-    </message>
-</context>
-<context>
-    <name>dde::network::NetworkDeviceRealize</name>
-    <message>
-        <source>Device disabled</source>
-        <translation>已停用裝置</translation>
-    </message>
-    <message>
-        <source>Connected but no Internet access</source>
-        <translation>已連線但不能存取網路</translation>
-    </message>
-    <message>
-        <source>Not connected</source>
-        <translation>未連線</translation>
-    </message>
-    <message>
-        <source>Network cable unplugged</source>
-        <translation>已拔除網路線</translation>
-    </message>
-    <message>
-        <source>Connecting</source>
-        <translation>正在連線</translation>
-    </message>
-    <message>
-        <source>Authenticating</source>
-        <translation>正在驗證</translation>
-    </message>
-    <message>
-        <source>Obtaining IP address</source>
-        <translation>取得 IP 位址中…</translation>
-    </message>
-    <message>
-        <source>Connected</source>
-        <translation>已連線</translation>
-    </message>
-    <message>
-        <source>Disconnected</source>
-        <translation>已斷線</translation>
-    </message>
-    <message>
-        <source>IP conflict</source>
-        <translation>IP位址衝突</translation>
-    </message>
-    <message>
-        <source>Failed</source>
-        <translation>連線失敗</translation>
-    </message>
-    <message>
-        <source>Obtaining address</source>
-        <translation>正在取得 IP 位址</translation>
-    </message>
-</context>
-<context>
-    <name>dde::network::NetworkProcesser</name>
-    <message>
-        <source>Wired Network</source>
-        <translation>有線網路</translation>
-    </message>
-    <message>
-        <source>Wired Network %1</source>
-        <translation>有線網路 %1</translation>
-    </message>
-    <message>
-        <source>Wireless Network</source>
-        <translation>無線網路</translation>
-    </message>
-    <message>
-        <source>Wireless Network %1</source>
-        <translation>無線網路 %1</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
