@@ -96,8 +96,8 @@ APItem::~APItem()
 
 void APItem::setSecure(bool isSecure)
 {
-    if (m_secureAction && isSecure)
-        m_secureAction->setIcon(QIcon::fromTheme("dcc_wireless_security"));
+    if (m_secureAction)
+        m_secureAction->setIcon(isSecure ? QIcon::fromTheme("dcc_wireless_security") : QIcon());
 
     setData(isSecure, SecureRole);
 }
@@ -283,7 +283,7 @@ WirelessPage::WirelessPage(WirelessDevice *dev, QWidget *parent)
         , m_sortDelayTimer(new QTimer(this))
         , m_autoConnectHideSsid("")
         , m_wirelessScanTimer(new QTimer(this))
-        , m_isAirplaneMode(false)
+        , m_available(true)
 {
     setAccessibleName("WirelessPage");
     qRegisterMetaType<APSortInfo>();
@@ -333,11 +333,11 @@ WirelessPage::WirelessPage(WirelessDevice *dev, QWidget *parent)
     connect(m_switch, &SwitchWidget::checkedChanged, this, &WirelessPage::onNetworkAdapterChanged);
     connect(m_device, & WirelessDevice::enableChanged, this, [ this ] (const bool enabled) {
         m_switch->blockSignals(true);
-        m_switch->setChecked(m_device->isEnabled() && !m_isAirplaneMode);
+        m_switch->setChecked(m_device->isEnabled() && m_available);
         m_switch->blockSignals(false);
         if (m_lvAP) {
             onUpdateAPItem();
-            m_lvAP->setVisible(enabled && !m_isAirplaneMode && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
+            m_lvAP->setVisible(enabled && m_available && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
             updateLayout(!m_lvAP->isHidden());
         }
         if (!enabled)
@@ -409,6 +409,10 @@ WirelessPage::WirelessPage(WirelessDevice *dev, QWidget *parent)
     connect(m_device, &WirelessDevice::connectionChanged, this, &WirelessPage::updateApStatus);
     connect(m_device, &WirelessDevice::deviceStatusChanged, this, &WirelessPage::updateApStatus);
     connect(m_device, &WirelessDevice::activeConnectionChanged, this, &WirelessPage::updateApStatus);
+    // 根据设备的interfaceFlags来判断是否禁用界面（当改变权限org.deepin.PermissionManager类）
+    // 或者通过开启或关闭飞行模式(此时会改变interfaceFlags的值)来决定是否禁用界面
+    connect(m_device, &WirelessDevice::availableChanged, this, &WirelessPage::onAvailableChanged);
+    onAvailableChanged(m_device->available());
 
     // init data
     const QList<AccessPoints *> lstUAccessPoints = m_device->accessPointItems();
@@ -435,7 +439,7 @@ WirelessPage::WirelessPage(WirelessDevice *dev, QWidget *parent)
     m_lvAP->setVisible(m_switch->checked() && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
     connect(m_device, &WirelessDevice::deviceStatusChanged, this, &WirelessPage::onDeviceStatusChanged);
     updateLayout(!m_lvAP->isHidden());
-    m_switch->setChecked(m_device->isEnabled());
+    m_switch->setChecked(m_device->isEnabled() && m_device->available());
     onDeviceStatusChanged(m_device->deviceStatus());
 
     HotspotController *hotspotController = NetworkController::instance()->hotspotController();
@@ -493,8 +497,8 @@ void WirelessPage::onDeviceStatusChanged(const DeviceStatus &stat)
 
     WifiStatus curWifiStatus = unavailable ? Wifi_Unavailable : Wifi_Available;
     if (curWifiStatus != m_preWifiStatus && stat > DeviceStatus::Disconnected) {
-        m_switch->setChecked(!unavailable && !m_isAirplaneMode);
-        onNetworkAdapterChanged(!unavailable && !m_isAirplaneMode);
+        m_switch->setChecked(!unavailable && m_available);
+        onNetworkAdapterChanged(!unavailable && m_available);
         m_preWifiStatus = curWifiStatus;
     }
 
@@ -563,12 +567,12 @@ void WirelessPage::onUpdateAccessPointInfo(const QList<AccessPoints *> &changeAp
     }
 }
 
-void WirelessPage::onAirplaneModeChanged(bool airplaneModeEnabled)
+void WirelessPage::onAvailableChanged(bool available)
 {
     if (m_switch && m_switch->switchButton()) {
-        m_switch->switchButton()->setDisabled(airplaneModeEnabled);
+        m_switch->switchButton()->setEnabled(available);
     }
-    setIsAirplaneMode(airplaneModeEnabled);
+    setAvaliable(available);
 }
 
 void WirelessPage::onUpdateAPItem()
@@ -591,6 +595,20 @@ void WirelessPage::onUpdateAPItem()
             connect(apItem->action(), &QAction::triggered, this, [ this, apItem ] {
                 this->onApWidgetEditRequested(apItem->data(APItem::PathRole).toString(), apItem->data(Qt::ItemDataRole::DisplayRole).toString());
             });
+            connect(ap, &AccessPoints::strengthChanged, this, [ this, ap ](int strength) {
+                if (!m_apItems.contains(ap->ssid()))
+                    return;
+
+                APItem *apItem = m_apItems[ap->ssid()];
+                apItem->setSignalStrength(strength);
+            });
+            connect(ap, &AccessPoints::securedChanged, this, [ this, ap ](bool secured) {
+                if (!m_apItems.contains(ap->ssid()))
+                    return;
+
+                APItem *apItem = m_apItems[ap->ssid()];
+                apItem->setSecure(secured);
+            });
         } else {
             apItem = m_apItems[ssid];
             removeSsid.removeOne(ssid);
@@ -652,19 +670,20 @@ void WirelessPage::appendConnectHidden()
     m_modelAP->appendRow(nonbc);
 }
 
-void WirelessPage::setIsAirplaneMode(bool isAirplaneMode)
+void WirelessPage::setAvaliable(bool available)
 {
-    if(m_isAirplaneMode != isAirplaneMode){
-        m_switch->setChecked(m_device->isEnabled() && !isAirplaneMode);
+    if(m_available != available){
+        m_switch->setChecked(m_device->isEnabled() && available);
+        m_lvAP->setVisible(m_device->isEnabled() && available && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
     }
-    m_isAirplaneMode = isAirplaneMode;
+    m_available = available;
 }
 
 void WirelessPage::onHotspotEnableChanged(const bool enabled)
 {
     m_closeHotspotBtn->setVisible(enabled);
     m_tipsGroup->setVisible(enabled);
-    m_lvAP->setVisible(!enabled && m_device->isEnabled() && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
+    m_lvAP->setVisible(!enabled && m_device->isEnabled() && m_available && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
     updateLayout(!m_lvAP->isHidden());
 }
 
@@ -687,7 +706,7 @@ void WirelessPage::onDeviceRemoved()
 
 void WirelessPage::onActivateApFailed(const AccessPoints* pAccessPoints)
 {
-    onApWidgetEditRequested(pAccessPoints->path(), connectionSsid(pAccessPoints->ssid()));
+    onApWidgetEditRequested(pAccessPoints->path(), pAccessPoints->ssid());
     for (auto it = m_apItems.cbegin(); it != m_apItems.cend(); ++it) {
         if ((it.value()->path() == pAccessPoints->path()) && (it.value()->uuid() == pAccessPoints->ssid())) {
             bool isReconnect = it.value()->setLoading(false);
