@@ -24,9 +24,18 @@ DockTestWidget::~DockTestWidget()
 
 void DockTestWidget::initDock()
 {
+    QWidget *itemParent = new QWidget(this);
+    itemParent->setAutoFillBackground(true);
+    QPalette palette = itemParent->palette();
+    palette.setColor(QPalette::ColorRole::Background, Qt::black);
+    itemParent->setPalette(palette);
+    QHBoxLayout *topLayout = new QHBoxLayout(this);
+    topLayout->addWidget(itemParent);
+    topLayout->addStretch();
+
     m_pluginInter->init(this);
     QWidget *pluginWidget = m_pluginInter->itemWidget(NETWORK_KEY);
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    QHBoxLayout *layout = new QHBoxLayout(itemParent);
     layout->setContentsMargins(20, 0, 20, 0);
     layout->addWidget(pluginWidget);
     layout->addStretch();
