@@ -114,6 +114,14 @@ public:
         }
         if (trayIcon) {
             m_applets.append({ QPointer<TrayIcon>(trayIcon), QPointer<DockPopupWindow>(nullptr) });
+            connect(trayIcon, &QObject::destroyed, this, [trayIcon, this] {
+                for (auto pair : m_applets) {
+                    if (pair.first.data() == trayIcon) {
+                        m_applets.removeAll(pair);
+                        break;
+                    }
+                }
+            });
         }
     }
 
@@ -131,9 +139,11 @@ protected:
                 if (!it.second || !it.second->isVisible())
                     continue;
 
-                QRect rect = it.second->rect();
-                rect.moveTo(it.second->mapToGlobal(rect.topLeft()));
-                if (!rect.contains(mouseEvent->globalPos())) {
+                QRect trayRect = it.first->rect();
+                QRect appletsRect = it.second->rect();
+                trayRect.moveTo(it.first->mapToGlobal(trayRect.topLeft()));
+                appletsRect.moveTo(it.second->mapToGlobal(appletsRect.topLeft()));
+                if (!trayRect.contains(mouseEvent->globalPos()) && !appletsRect.contains(mouseEvent->globalPos())) {
                     hidePopup();
                 }
                 break;
@@ -187,9 +197,12 @@ NetworkModule::NetworkModule(QObject *parent)
 QWidget *NetworkModule::content()
 {
     int msec = QTime::currentTime().msecsSinceStartOfDay();
-    if (!m_popupAppletManager->popupShown() && abs(msec - m_clickTime) > 200) {
+    if (abs(msec - m_clickTime) > 200) {
         m_clickTime = msec;
-        m_popupAppletManager->showPopupApplet();
+        if (m_popupAppletManager->popupShown())
+            m_popupAppletManager->hidePopup();
+        else
+            m_popupAppletManager->showPopupApplet();
     }
     return nullptr;
 }
