@@ -5,6 +5,8 @@
 #ifndef DSSTESTWIDGET_H
 #define DSSTESTWIDGET_H
 
+#include <DFloatingButton>
+
 #include <QWidget>
 
 namespace dss {
@@ -12,13 +14,10 @@ namespace dss {
     class NetworkPlugin;
   }
 }
-namespace Dtk {
-  namespace Widget {
-    class DFloatingButton;
-  }
-}
 
 class QPushButton;
+class FloatingButton;
+using namespace Dtk::Widget;
 
 class DssTestWidget : public QWidget
 {
@@ -28,13 +27,20 @@ public:
     DssTestWidget(QWidget *parent = Q_NULLPTR);
     ~DssTestWidget();
 
-private:
-    void loadDssPlugin();
-    bool eventFilter(QObject *watched, QEvent *event);
+protected slots:
+    void onClickButton();
 
 private:
     dss::module::NetworkPlugin *m_pModule;
-    Dtk::Widget::DFloatingButton *m_button;
+    FloatingButton *m_iconButton;
+};
+
+class FloatingButton : public DFloatingButton
+{
+    Q_OBJECT
+
+public:
+    FloatingButton(QWidget *parent = nullptr);
 };
 
 #endif // DSSTESTWIDGET_H
