@@ -171,7 +171,8 @@ void NetworkHandler::onDeviceInput() const
         break;
     }
     case 4: {
-        DSLController *ctrl = NetworkController::instance()->dslController();
+        NetworkController *networkCtrl = NetworkController::instance();
+        DSLController *ctrl = networkCtrl->dslController();
         QList<DSLItem *> items = ctrl->items();
         for (int i = 0; i < items.size(); i++) {
             DSLItem *item = items[i];
@@ -187,7 +188,22 @@ void NetworkHandler::onDeviceInput() const
                     ctrl->connectItem(item);
                 }
             } else {
-                ctrl->disconnectItem();
+                QList<WiredDevice *> wiredDevices;
+                QList<NetworkDeviceBase *> devices = networkCtrl->devices();
+                for (NetworkDeviceBase *device : devices) {
+                    if (device->deviceType() != DeviceType::Wired)
+                        continue;
+
+                    wiredDevices << static_cast<WiredDevice *>(device);
+                }
+                QStringList deviceList;
+                for (int i = 0; i < wiredDevices.size(); i++) {
+                    WiredDevice *device = wiredDevices[i];
+                    deviceList << QString("%1: %2").arg(i).arg(device->interface());
+                }
+                n = getInput("select device you want to disconnect", inputStr);
+                if (n >= 0 && n < wiredDevices.size())
+                    ctrl->disconnectItem(wiredDevices[n]);
             }
         }
         break;
