@@ -4,6 +4,9 @@
 
 #include "netutils.h"
 
+#include <QMetaType>
+#include <QDBusMetaType>
+
 #ifndef QT_DEBUG
 Q_LOGGING_CATEGORY(dncd, "dde.network.core.dev" , QtInfoMsg);
 #else
@@ -62,5 +65,22 @@ ConnectionStatus convertConnectionStatus(int sourceConnectionStatus)
     return ConnectionStatus::Unknown;
 }
 
+ConnectionStatus convertStateFromNetworkManager(NetworkManager::ActiveConnection::State state)
+{
+    switch (state) {
+    case NetworkManager::ActiveConnection::State::Activated:
+        return ConnectionStatus::Activated;
+    case NetworkManager::ActiveConnection::State::Activating:
+        return ConnectionStatus::Activating;
+    case NetworkManager::ActiveConnection::State::Deactivated:
+        return ConnectionStatus::Deactivated;
+    case NetworkManager::ActiveConnection::State::Deactivating:
+        return ConnectionStatus::Deactivating;
+    default:
+        break;
+    }
+    return ConnectionStatus::Deactivated;
+}
+
 }
 }
