@@ -72,6 +72,11 @@ QString ControllItems::activeConnection() const
     return m_activeConnection;
 }
 
+QDateTime ControllItems::timeStamp() const
+{
+    return m_timeStamp;
+}
+
 void ControllItems::setConnection(const QJsonObject &jsonObj)
 {
     m_connection->updateConnection(jsonObj);
@@ -82,6 +87,34 @@ void ControllItems::setActiveConnection(const QString &activeConnection)
     m_activeConnection = activeConnection;
 }
 
+void ControllItems::updateTimeStamp(QDateTime timeStamp)
+{
+    m_timeStamp = timeStamp;
+}
+
+QDebug operator<<(QDebug dbg, ConnectionStatus status)
+{
+    QDebugStateSaver stateSaver(dbg);
+    switch (status) {
+    case ConnectionStatus::Unknown:
+        dbg.nospace() << "Unknow";
+        break;
+    case ConnectionStatus::Activated:
+        dbg.nospace() << "Activated";
+        break;
+    case ConnectionStatus::Activating:
+        dbg.nospace() << "Activating";
+        break;
+    case ConnectionStatus::Deactivated:
+        dbg.nospace() << "Deactivated";
+        break;
+    case ConnectionStatus::Deactivating:
+        dbg.nospace() << "Deactivating";
+        break;
+    }
+    return dbg;
+}
+
 }
 
 }
