@@ -12,8 +12,12 @@
 #include "wireddevice.h"
 #include "wirelessdevice.h"
 #include "netutils.h"
-#include "realize/networkmanagerprocesser.h"
-#include "realize/networkinterprocesser.h"
+#include "networkmanagerprocesser.h"
+#include "networkinterprocesser.h"
+#include "connectivitychecker.h"
+#include "connectivityprocesser.h"
+
+#include <DConfig>
 
 const static QString networkService = "com.deepin.daemon.Network";
 const static QString networkPath = "/com/deepin/daemon/Network";
@@ -34,16 +38,22 @@ NetworkController::NetworkController()
     , m_dslController(Q_NULLPTR)
     , m_hotspotController(Q_NULLPTR)
 {
+    // 加载翻译文件
+    QTranslator *translator = new QTranslator(this);
+    translator->load(QString("/usr/share/dde-network-core/translations/dde-network-core_%1.qm").arg(QLocale::system().name()));
+    QCoreApplication::installTranslator(translator);
+
     if (m_serviceLoadType == ServiceLoadType::LoadFromManager)
-        m_processer = new NetworkManagerProcesser(this);
+        m_processer = new NetworkManagerProcesser(m_checkIpConflicted, this);
     else
         m_processer = new NetworkInterProcesser(m_sync, m_checkIpConflicted, this);
 
+    m_connectivityProcesser = new ConnectivityProcesser(m_processer, this);
     connect(m_processer, &NetworkProcesser::deviceAdded, this, &NetworkController::deviceAdded);
     connect(m_processer, &NetworkProcesser::deviceRemoved, this, &NetworkController::deviceRemoved);
-    connect(m_processer, &NetworkProcesser::connectivityChanged, this, &NetworkController::connectivityChanged);
     connect(m_processer, &NetworkProcesser::connectionChanged, this, &NetworkController::connectionChanged);
     connect(m_processer, &NetworkProcesser::activeConnectionChange, this, &NetworkController::activeConnectionChange);
+    connect(m_connectivityProcesser, &ConnectivityProcesser::connectivityChanged, this, &NetworkController::connectivityChanged);
 }
 
 NetworkController::~NetworkController()
@@ -110,7 +120,7 @@ QList<NetworkDeviceBase *> NetworkController::devices() const
 
 Connectivity NetworkController::connectivity()
 {
-    return m_processer->connectivity();
+    return m_connectivityProcesser->connectivity();
 }
 
 void NetworkController::retranslate()
