@@ -2,7 +2,7 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "realize/netinterface.h"
+#include "netinterface.h"
 #include "networkdevicebase.h"
 #include "netutils.h"
 
@@ -112,6 +112,11 @@ Connectivity NetworkDeviceBase::connectivity()
     return deviceRealize()->connectivity();
 }
 
+bool NetworkDeviceBase::ipConflicted()
+{
+    return deviceRealize()->ipConflicted();
+}
+
 void NetworkDeviceBase::setName(const QString &name)
 {
     if (m_name != name) {
@@ -174,3 +179,8 @@ bool NetworkDeviceBase::isEnabled() const
 {
     return m_deviceInterface->isEnabled();
 }
+
+bool NetworkDeviceBase::available() const
+{
+    return m_deviceInterface->available();
+}
