@@ -4,15 +4,17 @@
 
 #include "proxycontroller.h"
 
-const QString networkService = "com.deepin.daemon.Network";
-const QString networkPath    = "/com/deepin/daemon/Network/ProxyChains";
+
+const static QString networkService     = "com.deepin.daemon.Network";
+const static QString networkPath        = "/com/deepin/daemon/Network";
+const static QString proxyChainsPath    = "/com/deepin/daemon/Network/ProxyChains";
 
 using namespace dde::network;
 
-ProxyController::ProxyController(NetworkInter *networkInter, QObject *parent)
+ProxyController::ProxyController(QObject *parent)
     : QObject(parent)
-    , m_networkInter(networkInter)
-    , m_chainsInter(new ProxyChains(networkService, networkPath, QDBusConnection::sessionBus(), this))
+    , m_networkInter(new NetworkInter(networkService, networkPath, QDBusConnection::sessionBus(), this))
+    , m_chainsInter(new ProxyChains(networkService, proxyChainsPath, QDBusConnection::sessionBus(), this))
     , m_proxyMothod(ProxyMethod::Init)
 {
     Q_ASSERT(m_networkInter);
@@ -79,21 +81,6 @@ void ProxyController::setProxy(const SysProxyType &type, const QString &addr, co
     });
 }
 
-void ProxyController::setProxyAuth(const SysProxyType &type, const QString &userName, const QString &password, const bool enable)
-{
-    QString uType = convertSysProxyType(type);
-    QDBusPendingCallWatcher *w = new QDBusPendingCallWatcher(m_networkInter->asyncCall("SetProxyAuthentication", uType, userName, password, enable), this);
-    connect(w, &QDBusPendingCallWatcher::finished, w, &QDBusPendingCallWatcher::deleteLater);
-    connect(w, &QDBusPendingCallWatcher::finished, [ = ](QDBusPendingCallWatcher * self) {
-        Q_UNUSED(self);
-
-        QDBusPendingReply<QString, QString> reply = w->reply();
-        if (reply.isError()) return ;
-
-        queryProxyAuthByType(uType);
-    });
-}
-
 void ProxyController::setAppProxy(const AppProxyConfig &config)
 {
     m_chainsInter->Set(appProxyType(config.type), config.ip, config.port, config.username, config.password);
@@ -128,10 +115,8 @@ void ProxyController::querySysProxyData()
     static QStringList proxyTypes = {"http", "https", "ftp", "socks"};
 
     // 依次获取每种类型的数据，并填充到列表中
-    for (QString type : proxyTypes) {
+    for (QString type : proxyTypes)
         queryProxyDataByType(type);
-        queryProxyAuthByType(type);
-    }
 
     // 查询自动代理
     queryAutoProxy();
@@ -230,49 +215,6 @@ void ProxyController::queryProxyDataByType(const QString &type)
     });
 }
 
-void ProxyController::queryProxyAuthByType(const QString &type)
-{
-    SysProxyType uType = convertSysProxyType(type);
-    QDBusPendingCallWatcher *w = new QDBusPendingCallWatcher(m_networkInter->asyncCall("GetProxyAuthentication", type), this);
-    connect(w, &QDBusPendingCallWatcher::finished, w, &QDBusPendingCallWatcher::deleteLater);
-    connect(w, &QDBusPendingCallWatcher::finished, [ = ](QDBusPendingCallWatcher * self) {
-        Q_UNUSED(self);
-
-        QDBusPendingReply<QString, QString> reply = w->reply();
-        if (reply.isError()) return ;
-
-        // 先查找原来是否存在响应的代理，如果存在，就直接更新最新的数据
-        auto iterator = std::find_if(m_sysProxyConfig.begin(), m_sysProxyConfig.end(), [ = ] (SysProxyConfig conf) {
-            if (conf.type == uType) {
-                QString userName = reply.argumentAt(0).toString();
-                QString password = reply.argumentAt(1).toString();
-                bool enableAuth = reply.argumentAt(2).toBool();
-                if (enableAuth != conf.enableAuth ||
-                    userName != conf.userName ||
-                    password != conf.password) {
-                    conf.enableAuth = enableAuth;
-                    conf.userName = userName;
-                    conf.password = password;
-                    Q_EMIT proxyAuthChanged(conf);
-                }
-                return true;
-            }
-
-            return false;
-        });
-
-        if (iterator == m_sysProxyConfig.end()) {
-            SysProxyConfig proxyConfig;
-            proxyConfig.userName = reply.argumentAt(0).toString();
-            proxyConfig.password = reply.argumentAt(1).toString();
-            proxyConfig.enableAuth = reply.argumentAt(2).toBool();
-            proxyConfig.type = uType;
-            m_sysProxyConfig << proxyConfig;
-            Q_EMIT proxyAuthChanged(proxyConfig);
-        }
-    });
-}
-
 ProxyMethod ProxyController::convertProxyMethod(const QString &method)
 {
     // 根据传入的字符串获取代理模式的枚举值
