@@ -4,7 +4,7 @@
 
 #include "wireddevice.h"
 #include "networkconst.h"
-#include "realize/netinterface.h"
+#include "netinterface.h"
 
 using namespace dde::network;
 
