@@ -14,6 +14,7 @@ namespace network {
 class AccessPoints;
 class WirelessConnection;
 class NetworkDeviceRealize;
+class AccessPointProxy;
 /**
  * @brief 无线网络设备-无线网卡
  */
@@ -24,6 +25,7 @@ class WirelessDevice : public NetworkDeviceBase
     friend class NetworkController;
     friend class NetworkInterProcesser;
     friend class NetworkManagerProcesser;
+    friend class HotspotController_NM;
 
 public:
     bool isConnected() const override;                              // 是否连接网络，重写基类的虚函数
@@ -61,10 +63,6 @@ class AccessPoints : public QObject
 {
     Q_OBJECT
 
-    friend class WirelessDevice;
-    friend class WirelessDeviceInterRealize;
-    friend class DeviceManagerRealize;
-
     Q_PROPERTY(QString ssid READ ssid)
     Q_PROPERTY(int strength READ strength)
     Q_PROPERTY(bool secured READ secured)
@@ -77,11 +75,10 @@ class AccessPoints : public QObject
 public:
     enum class WlanType { wlan, wlan6 };
 
-protected:
-    AccessPoints(const QJsonObject &json, QObject *parent = Q_NULLPTR);
+    AccessPoints(AccessPointProxy *proxy, QObject *parent = nullptr);
+    ~AccessPoints();
 
 public:
-    ~AccessPoints();
     QString ssid() const;                                           // 网络SSID，对应于返回接口中的Ssid
     int strength() const;                                           // 信号强度，对应于返回接口中的Strength
     bool secured() const;                                           // 是否加密，对应于返回接口中的Secured
@@ -99,14 +96,8 @@ Q_SIGNALS:
     void connectionStatusChanged(ConnectionStatus);
     void securedChanged(bool);
 
-protected:
-    void updateAccessPoints(const QJsonObject &json);
-    void updateConnectionStatus(ConnectionStatus);
-
 private:
-    QJsonObject m_json;
-    QString m_devicePath;
-    ConnectionStatus m_status;
+    AccessPointProxy *m_proxy;
 };
 
 /**
@@ -118,6 +109,7 @@ class WirelessConnection: public ControllItems
     friend class WirelessDevice;
     friend class WirelessDeviceInterRealize;
     friend class DeviceManagerRealize;
+    friend class WirelessDeviceManagerRealize;
 
 public:
     WirelessConnection();
